@@ -48,26 +48,27 @@ var NAVTREEINDEX =
 [
 "annotated.html",
 "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a2ff96652e89b99f424c047a59e85850d",
-"class_v_s_t_g_u_i_1_1_c_check_box.html#aa66c6926e2cf2ae7a0abb802398253ca",
-"class_v_s_t_g_u_i_1_1_c_drop_source.html#ac1a8dbae9f236500f5a8391f33b469f3",
-"class_v_s_t_g_u_i_1_1_c_knob_base.html#a7d8fa859ed88b1daf2f04f5fd47b15dc",
-"class_v_s_t_g_u_i_1_1_c_option_menu.html",
-"class_v_s_t_g_u_i_1_1_c_row_column_view.html#a82ab61c920653e54d5721c2915810353",
-"class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ac3627a2e2abcfe4e6df2a77e4829446a",
-"class_v_s_t_g_u_i_1_1_c_text_button.html",
-"class_v_s_t_g_u_i_1_1_c_vertical_switch.html#a4433ff4e66b32c32a4b90436e369ec39",
-"class_v_s_t_g_u_i_1_1_c_vu_meter.html#addb2fa415e015ee482fa2cd9eba96af7ad4149164ae4bf90011d92a3dbfcce742",
-"class_v_s_t_g_u_i_1_1_i_data_package.html",
-"class_v_s_t_g_u_i_1_1_owning_pointer.html",
-"class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_model_binding_callbacks.html#a358733e54e4ffaaf714c9e1e9a948bb7",
-"class_v_s_t_g_u_i_1_1_u_i_description_listener.html#a61e940c1ab6e3c6b36ad5da2180838f1",
-"class_v_s_t_g_u_i_1_1_v_s_t3_editor.html#ae9b58248c96b9b9c138efdea1b53aedb",
-"exception_v_s_t_g_u_i_1_1_c_list_control.html#af62e08db33b12acfd7b3a1a20273ab82",
-"namespacemembers_0x62.html",
+"class_v_s_t_g_u_i_1_1_c_check_box.html",
+"class_v_s_t_g_u_i_1_1_c_draw_context.html#a622734e81b6fc1a89480d47fc4dc6f01",
+"class_v_s_t_g_u_i_1_1_c_kick_button.html#a8885308969382a38b3f72325fff3efc3",
+"class_v_s_t_g_u_i_1_1_c_movie_bitmap.html#ab84ddc9a4171391fa1aaab1e4aceeba4",
+"class_v_s_t_g_u_i_1_1_c_param_display.html#addb2fa415e015ee482fa2cd9eba96af7a60b39817e2fbec3a3ebaccd5fbbb93a9",
+"class_v_s_t_g_u_i_1_1_c_search_text_edit.html",
+"class_v_s_t_g_u_i_1_1_c_split_view.html#a54f2ef725a3284c7cadc1cc0c7dcc527",
+"class_v_s_t_g_u_i_1_1_c_text_button.html#af58ac07c30b89558b198cac6884f8c2c",
+"class_v_s_t_g_u_i_1_1_c_view.html#ae7b11de49c83518bc4e91feb6c2e9b9f",
+"class_v_s_t_g_u_i_1_1_final_action.html#aeab4b1101686b539f3de159820be39d6",
+"class_v_s_t_g_u_i_1_1_i_view_container_listener.html",
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html",
+"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a37ce269aca215ad88f2c4a05a9e6d456",
+"class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator.html#a75543acf144195808cb7e0b0074bd45d",
+"exception_v_s_t_g_u_i_1_1_buffer.html#ab23dbde36badcbd0d9dbc8ea21f928e3",
+"functions_vars_0x64.html",
+"namespacemembers_0x66.html",
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a01d261b33a34bd0a3bf951da935c3067",
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a6a9364bbd83bc1f0fc6ec2806d611974",
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html",
-"struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_scroll_view_creator.html#ad41eee1c02f657b8f38f1d481bfc30b2"
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a0a10a5d6efc9ffc1e4745a0092c9b42e",
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html",
+"struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_rocker_switch_creator.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
