@@ -75,8 +75,6 @@ var NAVTREEINDEX1 =
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#a64c95c189130160521d50820d9982242":[8,4,2,11],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#a68df5ad76f2e5c3a8e86c50c6e2ea63e":[8,3,1,7,9],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#a68df5ad76f2e5c3a8e86c50c6e2ea63e":[8,4,2,9],
-"class_v_s_t_g_u_i_1_1_c_anim_knob.html#aa4fe339a1b1b789b191573cc9e64f595":[8,3,1,7,0],
-"class_v_s_t_g_u_i_1_1_c_anim_knob.html#aa4fe339a1b1b789b191573cc9e64f595":[8,4,2,0],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ab53c15f66b61201baec35c57d529cc42":[8,3,1,7,7],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ab53c15f66b61201baec35c57d529cc42":[8,4,2,7],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ab96835f2793e9036892851d663e45249":[8,3,1,7,8],
@@ -85,6 +83,8 @@ var NAVTREEINDEX1 =
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#acde0a67d57f288d50b119435bd8cf104":[8,4,2,12],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ae39bb45e08ab3c4a4cfd51e724b876d3":[8,3,1,7,2],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#ae39bb45e08ab3c4a4cfd51e724b876d3":[8,4,2,2],
+"class_v_s_t_g_u_i_1_1_c_anim_knob.html#ae7629062965afe72510e702250c8895f":[8,3,1,7,0],
+"class_v_s_t_g_u_i_1_1_c_anim_knob.html#ae7629062965afe72510e702250c8895f":[8,4,2,0],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#af3a85d751115283a651e12bf590813a1":[8,3,1,7,3],
 "class_v_s_t_g_u_i_1_1_c_anim_knob.html#af3a85d751115283a651e12bf590813a1":[8,4,2,3],
 "class_v_s_t_g_u_i_1_1_c_animation_splash_screen.html":[8,1,0,28],
@@ -127,60 +127,62 @@ var NAVTREEINDEX1 =
 "class_v_s_t_g_u_i_1_1_c_animation_splash_screen.html#ad948aa070b4ae4b94324a4c42360fa65":[8,3,6,5],
 "class_v_s_t_g_u_i_1_1_c_auto_animation.html":[8,3,1,1],
 "class_v_s_t_g_u_i_1_1_c_auto_animation.html":[8,4,0],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0231609979b47e5decfd68f1f198af02":[8,3,1,1,13],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0231609979b47e5decfd68f1f198af02":[8,4,0,13],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0b6b12d61cfa8438b6a71497d2901194":[8,3,1,1,2],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0b6b12d61cfa8438b6a71497d2901194":[8,4,0,2],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a12551d78e54ffd9dc479bd115633c0b1":[8,3,1,1,19],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a12551d78e54ffd9dc479bd115633c0b1":[8,4,0,19],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a157ad241be4354121739aac80cf3cd3d":[8,3,1,1,15],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a157ad241be4354121739aac80cf3cd3d":[8,4,0,15],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a22ba26e8b6dd9b87e7b2b3aa0f94c7f6":[8,3,1,1,7],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a22ba26e8b6dd9b87e7b2b3aa0f94c7f6":[8,4,0,7],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a255ab875415900d903c1be948d5d19df":[8,3,1,1,21],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a255ab875415900d903c1be948d5d19df":[8,4,0,21],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a275bcd40970f1aaae9a958fd95d1e803":[8,3,1,1,22],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a275bcd40970f1aaae9a958fd95d1e803":[8,4,0,22],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a2aa48d074f315f79c09bce205e653418":[8,3,1,1,8],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a2aa48d074f315f79c09bce205e653418":[8,4,0,8],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a4433ff4e66b32c32a4b90436e369ec39":[8,3,1,1,10],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a4433ff4e66b32c32a4b90436e369ec39":[8,4,0,10],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a522467127f90bd5e2a6856e09b1b7bf2":[8,3,1,1,4],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a522467127f90bd5e2a6856e09b1b7bf2":[8,4,0,4],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a5dd3200e872b6337fa6eefe9599dd596":[8,3,1,1,12],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a5dd3200e872b6337fa6eefe9599dd596":[8,4,0,12],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6ca87040eb789d3fbe39defcafcbe6e6":[8,3,1,1,18],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6ca87040eb789d3fbe39defcafcbe6e6":[8,4,0,18],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6fcb05de762da60f52d18d665c3b67d8":[8,3,1,1,5],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6fcb05de762da60f52d18d665c3b67d8":[8,4,0,5],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a70252ffed7ec1cf8e1552751cab33c49":[8,3,1,1,26],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a70252ffed7ec1cf8e1552751cab33c49":[8,4,0,26],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0231609979b47e5decfd68f1f198af02":[8,3,1,1,14],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0231609979b47e5decfd68f1f198af02":[8,4,0,14],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0b6b12d61cfa8438b6a71497d2901194":[8,3,1,1,3],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a0b6b12d61cfa8438b6a71497d2901194":[8,4,0,3],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a12551d78e54ffd9dc479bd115633c0b1":[8,3,1,1,20],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a12551d78e54ffd9dc479bd115633c0b1":[8,4,0,20],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a157ad241be4354121739aac80cf3cd3d":[8,3,1,1,16],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a157ad241be4354121739aac80cf3cd3d":[8,4,0,16],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a22ba26e8b6dd9b87e7b2b3aa0f94c7f6":[8,3,1,1,8],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a22ba26e8b6dd9b87e7b2b3aa0f94c7f6":[8,4,0,8],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a234af440d2c60811fd889f5c48457c90":[8,3,1,1,0],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a234af440d2c60811fd889f5c48457c90":[8,4,0,0],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a255ab875415900d903c1be948d5d19df":[8,3,1,1,22],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a255ab875415900d903c1be948d5d19df":[8,4,0,22],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a275bcd40970f1aaae9a958fd95d1e803":[8,3,1,1,23],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a275bcd40970f1aaae9a958fd95d1e803":[8,4,0,23],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a2aa48d074f315f79c09bce205e653418":[8,3,1,1,9],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a2aa48d074f315f79c09bce205e653418":[8,4,0,9],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a4433ff4e66b32c32a4b90436e369ec39":[8,3,1,1,11],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a4433ff4e66b32c32a4b90436e369ec39":[8,4,0,11],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a522467127f90bd5e2a6856e09b1b7bf2":[8,3,1,1,5],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a522467127f90bd5e2a6856e09b1b7bf2":[8,4,0,5],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a58ba1c008d543a2c929d1083cb16526b":[8,3,1,1,2],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a58ba1c008d543a2c929d1083cb16526b":[8,4,0,2],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a5dd3200e872b6337fa6eefe9599dd596":[8,3,1,1,13],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a5dd3200e872b6337fa6eefe9599dd596":[8,4,0,13],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6ca87040eb789d3fbe39defcafcbe6e6":[8,3,1,1,19],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6ca87040eb789d3fbe39defcafcbe6e6":[8,4,0,19],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6fcb05de762da60f52d18d665c3b67d8":[8,3,1,1,6],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a6fcb05de762da60f52d18d665c3b67d8":[8,4,0,6],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a70252ffed7ec1cf8e1552751cab33c49":[8,3,1,1,27],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a70252ffed7ec1cf8e1552751cab33c49":[8,4,0,27],
 "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a73017258060539b2ea3cb6f2c37c16ee":[8,3,1,1,1],
 "class_v_s_t_g_u_i_1_1_c_auto_animation.html#a73017258060539b2ea3cb6f2c37c16ee":[8,4,0,1],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a79e674b14bc222779b90738ef8f6e096":[8,3,1,1,6],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a79e674b14bc222779b90738ef8f6e096":[8,4,0,6],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a7ca3bf73f0d19f84079ddd869582f150":[8,3,1,1,11],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a7ca3bf73f0d19f84079ddd869582f150":[8,4,0,11],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a8885308969382a38b3f72325fff3efc3":[8,3,1,1,24],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a8885308969382a38b3f72325fff3efc3":[8,4,0,24],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a97864020c1416b86454a8f12dc0f77f2":[8,3,1,1,16],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a97864020c1416b86454a8f12dc0f77f2":[8,4,0,16],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a9bc4cc2b9ac1bb18a948e6e7e8177fb4":[8,3,1,1,9],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a9bc4cc2b9ac1bb18a948e6e7e8177fb4":[8,4,0,9],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab29cf11489df5f8869bdd1b4f5c8ef8e":[8,3,1,1,25],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab29cf11489df5f8869bdd1b4f5c8ef8e":[8,4,0,25],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab53c15f66b61201baec35c57d529cc42":[8,3,1,1,17],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab53c15f66b61201baec35c57d529cc42":[8,4,0,17],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ae50a71e7927b3501b4ac0e461b4fee06":[8,3,1,1,14],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ae50a71e7927b3501b4ac0e461b4fee06":[8,4,0,14],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#aec53975ffc59ffaf3080db21af0d2f6e":[8,3,1,1,20],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#aec53975ffc59ffaf3080db21af0d2f6e":[8,4,0,20],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#aee94efa9f560fa95fcd47cc497e2f3d9":[8,3,1,1,0],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#aee94efa9f560fa95fcd47cc497e2f3d9":[8,4,0,0],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afd292af36cee8d646a779bd7c934111e":[8,3,1,1,23],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afd292af36cee8d646a779bd7c934111e":[8,4,0,23],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afe950609c73dfa6de5a3cbef008fbeff":[8,3,1,1,3],
-"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afe950609c73dfa6de5a3cbef008fbeff":[8,4,0,3],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a79e674b14bc222779b90738ef8f6e096":[8,3,1,1,7],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a79e674b14bc222779b90738ef8f6e096":[8,4,0,7],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a7ca3bf73f0d19f84079ddd869582f150":[8,3,1,1,12],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a7ca3bf73f0d19f84079ddd869582f150":[8,4,0,12],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a8885308969382a38b3f72325fff3efc3":[8,3,1,1,25],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a8885308969382a38b3f72325fff3efc3":[8,4,0,25],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a97864020c1416b86454a8f12dc0f77f2":[8,3,1,1,17],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a97864020c1416b86454a8f12dc0f77f2":[8,4,0,17],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a9bc4cc2b9ac1bb18a948e6e7e8177fb4":[8,3,1,1,10],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#a9bc4cc2b9ac1bb18a948e6e7e8177fb4":[8,4,0,10],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab29cf11489df5f8869bdd1b4f5c8ef8e":[8,3,1,1,26],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab29cf11489df5f8869bdd1b4f5c8ef8e":[8,4,0,26],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab53c15f66b61201baec35c57d529cc42":[8,3,1,1,18],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ab53c15f66b61201baec35c57d529cc42":[8,4,0,18],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ae50a71e7927b3501b4ac0e461b4fee06":[8,3,1,1,15],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#ae50a71e7927b3501b4ac0e461b4fee06":[8,4,0,15],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#aec53975ffc59ffaf3080db21af0d2f6e":[8,3,1,1,21],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#aec53975ffc59ffaf3080db21af0d2f6e":[8,4,0,21],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afd292af36cee8d646a779bd7c934111e":[8,3,1,1,24],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afd292af36cee8d646a779bd7c934111e":[8,4,0,24],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afe950609c73dfa6de5a3cbef008fbeff":[8,3,1,1,4],
+"class_v_s_t_g_u_i_1_1_c_auto_animation.html#afe950609c73dfa6de5a3cbef008fbeff":[8,4,0,4],
 "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view.html":[10,0,2,53],
 "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view.html#a522467127f90bd5e2a6856e09b1b7bf2":[10,0,2,53,2],
 "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view.html#a628758060bb2b806776d7654c53768ca":[10,0,2,53,6],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#adace5c068aa45fa60bf108bc2a418cd6":[8,1,0,14,15],
 "class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#ae7dbc92c0519048ef2f676c93b894a8c":[8,1,0,14,8],
 "class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#aed42844f904d1ec97d44d46b2afe24b8":[8,1,0,14,17],
-"class_v_s_t_g_u_i_1_1_c_check_box.html":[8,3,1,3],
-"class_v_s_t_g_u_i_1_1_c_check_box.html":[8,1,0,21],
-"class_v_s_t_g_u_i_1_1_c_check_box.html#a03a1979b5801db059ea479d867f41e59":[8,3,1,3,38]
+"class_v_s_t_g_u_i_1_1_c_check_box.html":[8,3,1,3]
 };
