@@ -1,5 +1,15 @@
 var NAVTREEINDEX13 =
 {
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html":[8,2,24],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html#a105ea595d253675e2340081250b5673c":[8,2,24,1],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html#a113a64c533cf7874c53b77e38f0a725c":[8,2,24,4],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html#a544b08cc88fc03333b6e93cb96ea5a40":[8,2,24,3],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html#ab1487d33294385c73a0f19b499077641":[8,2,24,0],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html#af2741a845353050aa58664796b9cc2c8":[8,2,24,2],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_mutable_step_value.html":[10,0,2,9,9],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_mutable_step_value.html#a5d989feb1d573e3bc84050d7ebb362cb":[10,0,2,9,9,0],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_preference.html":[8,2,25],
+"class_v_s_t_g_u_i_1_1_standalone_1_1_i_preference.html#a27ed04315b5e6a530d1908cbd5f592fd":[8,2,25,0],
 "class_v_s_t_g_u_i_1_1_standalone_1_1_i_preference.html#ac61d99aecfc43390721d2df9baeb2ed4":[8,2,25,1],
 "class_v_s_t_g_u_i_1_1_standalone_1_1_i_range_value_converter.html":[10,0,2,9,10],
 "class_v_s_t_g_u_i_1_1_standalone_1_1_i_range_value_converter.html#a493012b96697d36606136fe2dc8c1fdc":[10,0,2,9,10,0],
@@ -184,45 +194,45 @@ var NAVTREEINDEX13 =
 "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter.html#a6460e8f1c668888059c8ec75f8eab1fa":[8,2,15,2],
 "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter.html#a8f7e66e5be63bf00195572a29f15706a":[8,2,15,1],
 "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter.html#acf538bd0165724f6246c2eb3c58ad9a5":[8,2,15,4],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html":[8,1,9,4],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#a2c0f4dd1283306d4382c4f5737d54d77":[8,1,9,4,0],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#a9efc3797ee6322dac19ed8f0ff9a90b5":[8,1,9,4,3],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#ae53093b6275acc808b0eb0aa20653686":[8,1,9,4,4],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#aeedbe4fb8ecdf93cfc76ea85e90543b1":[8,1,9,4,5],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#af18d2b53ddaec5cafefbf91cf63ef226":[8,1,9,4,2],
-"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#af55ded018641cd986cf7ea8b3e9e3ec6":[8,1,9,4,1],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html":[8,1,11,4],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#a2c0f4dd1283306d4382c4f5737d54d77":[8,1,11,4,0],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#a9efc3797ee6322dac19ed8f0ff9a90b5":[8,1,11,4,3],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#ae53093b6275acc808b0eb0aa20653686":[8,1,11,4,4],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#aeedbe4fb8ecdf93cfc76ea85e90543b1":[8,1,11,4,5],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#af18d2b53ddaec5cafefbf91cf63ef226":[8,1,11,4,2],
+"class_v_s_t_g_u_i_1_1_static_list_control_configurator.html#af55ded018641cd986cf7ea8b3e9e3ec6":[8,1,11,4,1],
 "class_v_s_t_g_u_i_1_1_std_out_stream.html":[10,0,2,100],
 "class_v_s_t_g_u_i_1_1_std_out_stream.html#a5453f05e2a26c26eddbe6043a8f6df36":[10,0,2,100,2],
 "class_v_s_t_g_u_i_1_1_std_out_stream.html#a766d0071693bbd5930f98a799ce234d2":[10,0,2,100,1],
 "class_v_s_t_g_u_i_1_1_std_out_stream.html#a87bc681fc5d50371c52790c427cbc609":[10,0,2,100,0],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html":[8,1,9,5],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a023c87ab76ba8129b410d84cf7f616e9":[8,1,9,5,14],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a066cf1eb340212960f527b08bb1cb311":[8,1,9,5,5],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a105d8dd772742e8af35efd70786d4c36":[8,1,9,5,6],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a12490ee7a38a8bd242016d17542ee918":[8,1,9,5,3],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a2d0e09600c0d157dfbc921f8457166d1":[8,1,9,5,17],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a40330e605721feb6290ede56c0dd4657":[8,1,9,5,16],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a464dedd8ea4ede9e0dfab77c6e87c73e":[8,1,9,5,19],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a4dbd403066f2df9f1aae251a2d548420":[8,1,9,5,2],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a55add0acdb40099ff7a720836e2203f7":[8,1,9,5,25],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a6721a812310fdb9e0dfb60c562fdaf1c":[8,1,9,5,15],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a74f51a9e900353a7dfbba90e78e9485f":[8,1,9,5,8],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a7c3de3e408dadb0c7c7066288e5ac857":[8,1,9,5,4],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a7ef16cb13f2da623c1083b1ac6c9beb1":[8,1,9,5,12],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a9901bb437bd3a1c196eb2f7b0d5bfa44":[8,1,9,5,21],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a9bafb95366e382dcfd0e08a07396c9b5":[8,1,9,5,26],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#aa0ed77b9ef6964efb9b6acad4cd36a41":[8,1,9,5,11],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ab16ed28b6fc0bb798a03687087e68aa9":[8,1,9,5,27],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ab5203d378f9a5e3978de3c6b50f09750":[8,1,9,5,20],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#abb733222ee0828c799f8fe9b8ad47a6d":[8,1,9,5,7],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#acd49f85a404dbae6d29f2c18605086a8":[8,1,9,5,24],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ad0bbe71f8de22af375dfbbd4e34da3ec":[8,1,9,5,13],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ad2414b926b8266b628c3f244c6575ab8":[8,1,9,5,1],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ae0bff4405afebc3c048bf32f0742470d":[8,1,9,5,22],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ae9f75a13539fdaf0325b8cd517629f09":[8,1,9,5,23],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#aeaf6af4b5d771d43a2692ea3e1ef5342":[8,1,9,5,18],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#af0794492e0a883d5b29c892f3cd0356f":[8,1,9,5,9],
-"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#af7eabc874b62944b7607f8472b951ef7":[8,1,9,5,10],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html":[8,1,11,5],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a023c87ab76ba8129b410d84cf7f616e9":[8,1,11,5,14],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a066cf1eb340212960f527b08bb1cb311":[8,1,11,5,5],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a105d8dd772742e8af35efd70786d4c36":[8,1,11,5,6],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a12490ee7a38a8bd242016d17542ee918":[8,1,11,5,3],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a2d0e09600c0d157dfbc921f8457166d1":[8,1,11,5,17],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a40330e605721feb6290ede56c0dd4657":[8,1,11,5,16],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a464dedd8ea4ede9e0dfab77c6e87c73e":[8,1,11,5,19],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a4dbd403066f2df9f1aae251a2d548420":[8,1,11,5,2],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a55add0acdb40099ff7a720836e2203f7":[8,1,11,5,25],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a6721a812310fdb9e0dfb60c562fdaf1c":[8,1,11,5,15],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a74f51a9e900353a7dfbba90e78e9485f":[8,1,11,5,8],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a7c3de3e408dadb0c7c7066288e5ac857":[8,1,11,5,4],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a7ef16cb13f2da623c1083b1ac6c9beb1":[8,1,11,5,12],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a9901bb437bd3a1c196eb2f7b0d5bfa44":[8,1,11,5,21],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#a9bafb95366e382dcfd0e08a07396c9b5":[8,1,11,5,26],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#aa0ed77b9ef6964efb9b6acad4cd36a41":[8,1,11,5,11],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ab16ed28b6fc0bb798a03687087e68aa9":[8,1,11,5,27],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ab5203d378f9a5e3978de3c6b50f09750":[8,1,11,5,20],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#abb733222ee0828c799f8fe9b8ad47a6d":[8,1,11,5,7],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#acd49f85a404dbae6d29f2c18605086a8":[8,1,11,5,24],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ad0bbe71f8de22af375dfbbd4e34da3ec":[8,1,11,5,13],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ad2414b926b8266b628c3f244c6575ab8":[8,1,11,5,1],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ae0bff4405afebc3c048bf32f0742470d":[8,1,11,5,22],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#ae9f75a13539fdaf0325b8cd517629f09":[8,1,11,5,23],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#aeaf6af4b5d771d43a2692ea3e1ef5342":[8,1,11,5,18],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#af0794492e0a883d5b29c892f3cd0356f":[8,1,11,5,9],
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#af7eabc874b62944b7607f8472b951ef7":[8,1,11,5,10],
 "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html":[10,0,2,48],
 "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html#a1b12fc1bb989218b06d9131bb83294c7":[10,0,2,48,0],
 "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html#ae0c3d1b6fcff48fe783ff78b245f8675":[10,0,2,48,1],
@@ -239,15 +249,5 @@ var NAVTREEINDEX13 =
 "class_v_s_t_g_u_i_1_1_u_i_attributes.html#a26b3e53bb0eccf39bc9330bd14f9d5d6":[10,0,2,108,25],
 "class_v_s_t_g_u_i_1_1_u_i_attributes.html#a2a023d67471cd59df7973fb7fa520a78":[10,0,2,108,0],
 "class_v_s_t_g_u_i_1_1_u_i_attributes.html#a2b32fb3bc91d42d9523b29c399cf19a3":[10,0,2,108,23],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a2cc9198799e806efa3e250856d646a46":[10,0,2,108,2],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a37ce269aca215ad88f2c4a05a9e6d456":[10,0,2,108,3],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a3e7c43979b228862c9138245de09a852":[10,0,2,108,19],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a41b34a739cfb66a7dd159cbd46beb7b4":[10,0,2,108,21],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a4aa9873f4bdc67bbd0b4a7c47390a106":[10,0,2,108,30],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a4ff53b80efd97caf6b0f9a2193cb845a":[10,0,2,108,29],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a601fba11e6d33fea254dbbc1f12b503b":[10,0,2,108,8],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a6080c68ac82148bc668e9218b1d39854":[10,0,2,108,20],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a61933d378a3f02b296526e84e58e2496":[10,0,2,108,11],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a6b1df37ebb6d40d925ff93b5bfe0cd83":[10,0,2,108,31],
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a7339bcc175adc3c21220a5cf6bb6e187":[10,0,2,108,32]
+"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a2cc9198799e806efa3e250856d646a46":[10,0,2,108,2]
 };
