@@ -1,5 +1,15 @@
 var NAVTREEINDEX17 =
 {
+"functions_vars_0x64.html":[10,3,2,4],
+"functions_vars_0x65.html":[10,3,2,5],
+"functions_vars_0x66.html":[10,3,2,6],
+"functions_vars_0x67.html":[10,3,2,7],
+"functions_vars_0x68.html":[10,3,2,8],
+"functions_vars_0x69.html":[10,3,2,9],
+"functions_vars_0x6a.html":[10,3,2,10],
+"functions_vars_0x6b.html":[10,3,2,11],
+"functions_vars_0x6c.html":[10,3,2,12],
+"functions_vars_0x6d.html":[10,3,2,13],
 "functions_vars_0x6e.html":[10,3,2,14],
 "functions_vars_0x6f.html":[10,3,2,15],
 "functions_vars_0x70.html":[10,3,2,16],
@@ -23,8 +33,8 @@ var NAVTREEINDEX17 =
 "group__new__in__4__1.html":[8,1,1],
 "group__new__in__4__10.html":[8,1,2],
 "group__new__in__4__10.html#ga358d2e2397ca11ccd17553e3c40e7901":[8,1,2,1],
-"group__new__in__4__10.html#ga62e791b9e7fba05bf64b8634ecc30a17":[8,1,8,2,2],
 "group__new__in__4__10.html#ga62e791b9e7fba05bf64b8634ecc30a17":[8,1,2,3],
+"group__new__in__4__10.html#ga62e791b9e7fba05bf64b8634ecc30a17":[8,1,10,2,2],
 "group__new__in__4__10.html#gacb669fbf9e184809ae58b5cfa4741088":[8,1,2,2],
 "group__new__in__4__11.html":[8,1,3],
 "group__new__in__4__11.html#ga010ad00fd4fa3deaa934b01b4a4e1ba1":[8,1,3,41],
@@ -133,18 +143,24 @@ var NAVTREEINDEX17 =
 "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca945d5e233cf7d6240f6b783b36a374ff":[8,1,3,21,1],
 "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bcab1ca34f82e83c52b010f86955f264e05":[8,1,3,21,2],
 "group__new__in__4__12.html":[8,1,4],
-"group__new__in__4__2.html":[8,1,5],
-"group__new__in__4__3.html":[8,1,6],
-"group__new__in__4__5.html":[8,1,7],
-"group__new__in__4__7.html":[8,1,8],
-"group__new__in__4__7.html#ga03f7f125f798852b8ee0c8fb952c3cda":[8,1,8,13],
-"group__new__in__4__7.html#ga3cbd589c354a1539328b774d6ec68779":[8,1,8,12],
-"group__new__in__4__7.html#gaf5b1db19bf784e98be785e3d4382fa68":[8,1,8,14],
-"group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a5fb63579fc981698f97d55bfecb213ea":[8,1,8,12,0],
-"group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a6adf97f83acf6453d4a6a4b1070f3754":[8,1,8,12,2],
-"group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a6bc362dbf494c61ea117fe3c71ca48a5":[8,1,8,12,1],
-"group__new__in__4__9.html":[8,1,9],
-"group__new__in__4__9.html#ga00b08005394f4061d1c0b5320426a91e":[8,1,9,7],
+"group__new__in__4__12__1.html":[8,1,5],
+"group__new__in__4__12__1.html#ga4cca024629bfc0d7a7a2cf77eb386497":[8,1,4,1,8],
+"group__new__in__4__12__1.html#ga4cca024629bfc0d7a7a2cf77eb386497":[8,1,5,1],
+"group__new__in__4__12__1.html#ga92f1d595936949be30bb88842e3b14c0":[8,1,5,0],
+"group__new__in__4__12__1.html#ga92f1d595936949be30bb88842e3b14c0":[8,1,4,1,3],
+"group__new__in__4__12__2.html":[8,1,6],
+"group__new__in__4__2.html":[8,1,7],
+"group__new__in__4__3.html":[8,1,8],
+"group__new__in__4__5.html":[8,1,9],
+"group__new__in__4__7.html":[8,1,10],
+"group__new__in__4__7.html#ga03f7f125f798852b8ee0c8fb952c3cda":[8,1,10,13],
+"group__new__in__4__7.html#ga3cbd589c354a1539328b774d6ec68779":[8,1,10,12],
+"group__new__in__4__7.html#gaf5b1db19bf784e98be785e3d4382fa68":[8,1,10,14],
+"group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a5fb63579fc981698f97d55bfecb213ea":[8,1,10,12,0],
+"group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a6adf97f83acf6453d4a6a4b1070f3754":[8,1,10,12,2],
+"group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a6bc362dbf494c61ea117fe3c71ca48a5":[8,1,10,12,1],
+"group__new__in__4__9.html":[8,1,11],
+"group__new__in__4__9.html#ga00b08005394f4061d1c0b5320426a91e":[8,1,11,7],
 "group__standalone.html":[8,2],
 "group__standalone.html#ga1e4e8a3cc28862237995f7def08e349d":[8,2,39],
 "group__standalone.html#ga476342970f954b62d70552bcbb5ee509":[8,2,42],
@@ -170,30 +186,30 @@ var NAVTREEINDEX17 =
 "modules.html":[8],
 "namespace_v_s_t3_editor.html":[9,0,0],
 "namespace_v_s_t3_editor.html":[10,0,0],
-"namespace_v_s_t3_editor_internal.html":[10,0,1],
 "namespace_v_s_t3_editor_internal.html":[9,0,1],
+"namespace_v_s_t3_editor_internal.html":[10,0,1],
 "namespace_v_s_t_g_u_i.html":[10,0,2],
 "namespace_v_s_t_g_u_i.html":[9,0,2],
-"namespace_v_s_t_g_u_i_1_1_animation.html":[9,0,2,0],
 "namespace_v_s_t_g_u_i_1_1_animation.html":[10,0,2,0],
-"namespace_v_s_t_g_u_i_1_1_bitmap_filter.html":[9,0,2,1],
+"namespace_v_s_t_g_u_i_1_1_animation.html":[9,0,2,0],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter.html":[10,0,2,1],
+"namespace_v_s_t_g_u_i_1_1_bitmap_filter.html":[9,0,2,1],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard.html":[10,0,2,1,0],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard.html":[9,0,2,1,0],
-"namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard_1_1_property.html":[10,0,2,1,0,0],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard_1_1_property.html":[9,0,2,1,0,0],
-"namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html":[9,0,2,3],
+"namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard_1_1_property.html":[10,0,2,1,0,0],
 "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html":[10,0,2,3],
+"namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html":[9,0,2,3],
 "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html":[9,0,2,4],
 "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html":[10,0,2,4],
 "namespace_v_s_t_g_u_i_1_1_call.html":[9,0,2,2],
 "namespace_v_s_t_g_u_i_1_1_call.html":[10,0,2,2],
-"namespace_v_s_t_g_u_i_1_1_constants.html":[10,0,2,5],
 "namespace_v_s_t_g_u_i_1_1_constants.html":[9,0,2,5],
-"namespace_v_s_t_g_u_i_1_1_detail.html":[9,0,2,6],
+"namespace_v_s_t_g_u_i_1_1_constants.html":[10,0,2,5],
 "namespace_v_s_t_g_u_i_1_1_detail.html":[10,0,2,6],
-"namespace_v_s_t_g_u_i_1_1_event_private.html":[9,0,2,7],
+"namespace_v_s_t_g_u_i_1_1_detail.html":[9,0,2,6],
 "namespace_v_s_t_g_u_i_1_1_event_private.html":[10,0,2,7],
+"namespace_v_s_t_g_u_i_1_1_event_private.html":[9,0,2,7],
 "namespace_v_s_t_g_u_i_1_1_pixel_buffer.html":[10,0,2,8],
 "namespace_v_s_t_g_u_i_1_1_pixel_buffer.html":[9,0,2,8],
 "namespace_v_s_t_g_u_i_1_1_pixel_buffer_1_1_private.html":[9,0,2,8,0],
@@ -206,26 +222,26 @@ var NAVTREEINDEX17 =
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_async.html":[9,0,2,9,1],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html":[9,0,2,9,2],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html":[10,0,2,9,2],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html":[9,0,2,9,3],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html":[10,0,2,9,3],
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html":[9,0,2,9,3],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html":[9,0,2,9,4],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html":[10,0,2,9,4],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html":[10,0,2,9,4,0],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html":[9,0,2,9,4,0],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html":[9,0,2,9,5],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html":[10,0,2,9,5],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_value.html":[9,0,2,9,6],
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html":[9,0,2,9,5],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_value.html":[10,0,2,9,6],
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_value.html":[9,0,2,9,6],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_detail.html":[10,0,2,9,6,0],
 "namespace_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_detail.html":[9,0,2,9,6,0],
-"namespace_v_s_t_g_u_i_1_1_string.html":[10,0,2,10],
 "namespace_v_s_t_g_u_i_1_1_string.html":[9,0,2,10],
+"namespace_v_s_t_g_u_i_1_1_string.html":[10,0,2,10],
 "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html":[10,0,2,11],
 "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html":[9,0,2,11],
-"namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html":[10,0,2,12],
 "namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html":[9,0,2,12],
-"namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html":[10,0,2,13],
+"namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html":[10,0,2,12],
 "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html":[9,0,2,13],
+"namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html":[10,0,2,13],
 "namespace_v_s_t_g_u_i_1_1_xml.html":[10,0,2,14],
 "namespace_v_s_t_g_u_i_1_1_xml.html":[9,0,2,14],
 "namespacemembers.html":[9,1,0,0],
@@ -233,21 +249,5 @@ var NAVTREEINDEX17 =
 "namespacemembers_0x62.html":[9,1,0,1],
 "namespacemembers_0x63.html":[9,1,0,2],
 "namespacemembers_0x64.html":[9,1,0,3],
-"namespacemembers_0x65.html":[9,1,0,4],
-"namespacemembers_0x66.html":[9,1,0,5],
-"namespacemembers_0x67.html":[9,1,0,6],
-"namespacemembers_0x68.html":[9,1,0,7],
-"namespacemembers_0x69.html":[9,1,0,8],
-"namespacemembers_0x6a.html":[9,1,0,9],
-"namespacemembers_0x6b.html":[9,1,0,10],
-"namespacemembers_0x6c.html":[9,1,0,11],
-"namespacemembers_0x6d.html":[9,1,0,12],
-"namespacemembers_0x6e.html":[9,1,0,13],
-"namespacemembers_0x6f.html":[9,1,0,14],
-"namespacemembers_0x70.html":[9,1,0,15],
-"namespacemembers_0x71.html":[9,1,0,16],
-"namespacemembers_0x72.html":[9,1,0,17],
-"namespacemembers_0x73.html":[9,1,0,18],
-"namespacemembers_0x74.html":[9,1,0,19],
-"namespacemembers_0x75.html":[9,1,0,20]
+"namespacemembers_0x65.html":[9,1,0,4]
 };
