@@ -1,5 +1,21 @@
 var NAVTREEINDEX18 =
 {
+"namespacemembers_0x66.html":[9,1,0,5],
+"namespacemembers_0x67.html":[9,1,0,6],
+"namespacemembers_0x68.html":[9,1,0,7],
+"namespacemembers_0x69.html":[9,1,0,8],
+"namespacemembers_0x6a.html":[9,1,0,9],
+"namespacemembers_0x6b.html":[9,1,0,10],
+"namespacemembers_0x6c.html":[9,1,0,11],
+"namespacemembers_0x6d.html":[9,1,0,12],
+"namespacemembers_0x6e.html":[9,1,0,13],
+"namespacemembers_0x6f.html":[9,1,0,14],
+"namespacemembers_0x70.html":[9,1,0,15],
+"namespacemembers_0x71.html":[9,1,0,16],
+"namespacemembers_0x72.html":[9,1,0,17],
+"namespacemembers_0x73.html":[9,1,0,18],
+"namespacemembers_0x74.html":[9,1,0,19],
+"namespacemembers_0x75.html":[9,1,0,20],
 "namespacemembers_0x76.html":[9,1,0,21],
 "namespacemembers_0x77.html":[9,1,0,22],
 "namespacemembers_0x7e.html":[9,1,0,23],
@@ -33,19 +49,21 @@ var NAVTREEINDEX18 =
 "page_news_and_changes.html#hidpi_support":[2,3],
 "page_news_and_changes.html#ios_support":[2,4],
 "page_news_and_changes.html#new_stuff":[2,1],
-"page_news_and_changes.html#version4_0":[2,1,12],
-"page_news_and_changes.html#version4_1":[2,1,11],
-"page_news_and_changes.html#version4_10":[2,1,2],
-"page_news_and_changes.html#version4_11":[2,1,1],
-"page_news_and_changes.html#version4_12":[2,1,0],
-"page_news_and_changes.html#version4_2":[2,1,10],
-"page_news_and_changes.html#version4_3":[2,1,9],
-"page_news_and_changes.html#version4_4":[2,1,8],
-"page_news_and_changes.html#version4_5":[2,1,7],
-"page_news_and_changes.html#version4_6":[2,1,6],
-"page_news_and_changes.html#version4_7":[2,1,5],
-"page_news_and_changes.html#version4_8":[2,1,4],
-"page_news_and_changes.html#version4_9":[2,1,3],
+"page_news_and_changes.html#version4_0":[2,1,14],
+"page_news_and_changes.html#version4_1":[2,1,13],
+"page_news_and_changes.html#version4_10":[2,1,4],
+"page_news_and_changes.html#version4_11":[2,1,3],
+"page_news_and_changes.html#version4_12":[2,1,2],
+"page_news_and_changes.html#version4_12_1":[2,1,1],
+"page_news_and_changes.html#version4_12_2":[2,1,0],
+"page_news_and_changes.html#version4_2":[2,1,12],
+"page_news_and_changes.html#version4_3":[2,1,11],
+"page_news_and_changes.html#version4_4":[2,1,10],
+"page_news_and_changes.html#version4_5":[2,1,9],
+"page_news_and_changes.html#version4_6":[2,1,8],
+"page_news_and_changes.html#version4_7":[2,1,7],
+"page_news_and_changes.html#version4_8":[2,1,6],
+"page_news_and_changes.html#version4_9":[2,1,5],
 "page_news_and_changes.html#version4_introduction":[2,0],
 "page_previous_new_stuff.html":[2,5],
 "page_previous_new_stuff.html#about_deprecation":[2,5,2],
@@ -231,23 +249,5 @@ var NAVTREEINDEX18 =
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects.html#ac218747c8a53412e7928ce690dd886ca":[8,3,0,0,0,1],
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects.html#adac116554b543b7c4228c018a85882f5":[8,3,0,0,0,3],
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects.html#ae4590118f1051be2a1e7f04a2e262fb9":[8,3,0,0,0,2],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html":[8,3,0,0,1],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a01d261b33a34bd0a3bf951da935c3067":[8,3,0,0,1,5],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a03c996f9fcf0e10baeb3e700be0c409a":[8,3,0,0,1,4],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a086776ce4baec0a80943a8eea354fac9":[8,3,0,0,1,3],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a190ea2debf9e9b8f762f20615fb71bf9":[8,3,0,0,1,15],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a217b7780727dcad55d2fbb81ed723b1e":[8,3,0,0,1,25],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a22183e4585775fe3552f8a49a5bc330b":[8,3,0,0,1,27],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a3b07e17f5a81a5c5ae52068b87704a53":[8,3,0,0,1,11],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a481d943e2b56180300cd64fe1689dee1":[8,3,0,0,1,1],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a4ba37a4566a06d14c6811516c5595cb1":[8,3,0,0,1,2],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a6c4243b462853b25cdd48c164fe4277a":[8,3,0,0,1,17],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a6d9f52e7c58cb7472025e716b060b380":[8,3,0,0,1,9],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a75da6aee5022106edcbd8ad3ea6f543e":[8,3,0,0,1,6],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a7ebfcd1bdb347f2d380ca6a1188d4340":[8,3,0,0,1,23],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a82239cf30a44e84fb668477f221663db":[8,3,0,0,1,22],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a8356a721fff4d1f369d406c9da9df548":[8,3,0,0,1,20],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a9aa7d5ad803eb07a0f3afe19c0212726":[8,3,0,0,1,10],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a9dd33631270f85952ac026501d6b0015":[8,3,0,0,1,19],
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aa3d0cd46ab50a61ee8dd77f85f6ebea0":[8,3,0,0,1,18]
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html":[8,3,0,0,1]
 };
