@@ -1,5 +1,23 @@
 var NAVTREEINDEX19 =
 {
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a01d261b33a34bd0a3bf951da935c3067":[8,3,0,0,1,5],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a03c996f9fcf0e10baeb3e700be0c409a":[8,3,0,0,1,4],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a086776ce4baec0a80943a8eea354fac9":[8,3,0,0,1,3],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a190ea2debf9e9b8f762f20615fb71bf9":[8,3,0,0,1,15],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a217b7780727dcad55d2fbb81ed723b1e":[8,3,0,0,1,25],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a22183e4585775fe3552f8a49a5bc330b":[8,3,0,0,1,27],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a3b07e17f5a81a5c5ae52068b87704a53":[8,3,0,0,1,11],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a481d943e2b56180300cd64fe1689dee1":[8,3,0,0,1,1],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a4ba37a4566a06d14c6811516c5595cb1":[8,3,0,0,1,2],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a6c4243b462853b25cdd48c164fe4277a":[8,3,0,0,1,17],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a6d9f52e7c58cb7472025e716b060b380":[8,3,0,0,1,9],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a75da6aee5022106edcbd8ad3ea6f543e":[8,3,0,0,1,6],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a7ebfcd1bdb347f2d380ca6a1188d4340":[8,3,0,0,1,23],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a82239cf30a44e84fb668477f221663db":[8,3,0,0,1,22],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a8356a721fff4d1f369d406c9da9df548":[8,3,0,0,1,20],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a9aa7d5ad803eb07a0f3afe19c0212726":[8,3,0,0,1,10],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a9dd33631270f85952ac026501d6b0015":[8,3,0,0,1,19],
+"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aa3d0cd46ab50a61ee8dd77f85f6ebea0":[8,3,0,0,1,18],
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aa3f45c018aa1a4b39c390e3d49757f6f":[8,3,0,0,1,24],
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aa54916aa86c4f5b7b6c172c243996b2d":[8,3,0,0,1,26],
 "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aab454e846ff98f312a168529bef56559":[8,3,0,0,1,13],
@@ -59,21 +77,21 @@ var NAVTREEINDEX19 =
 "struct_v_s_t_g_u_i_1_1_c_knob_base_1_1_mouse_editing_state.html#ace4c5db3aaccd7960f7360c858a4737c":[10,0,2,39,0,2],
 "struct_v_s_t_g_u_i_1_1_c_knob_base_1_1_mouse_editing_state.html#ae639c1d82241ae5d80142ab206cf87ac":[10,0,2,39,0,5],
 "struct_v_s_t_g_u_i_1_1_c_knob_base_1_1_mouse_editing_state.html#af97633e288d6f26e4de295157508f421":[10,0,2,39,0,0],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html":[8,1,9,0,0],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#a44e93d58ebc76240ed5fefc71cd7b157":[8,1,9,0,0,4],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#a56057819f78d9070f20423e5b3cdefa0":[8,1,9,0,0,3],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#a74f8f658773f84bd6e8b58c35dd48ad0":[8,1,9,0,0,0],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#aa62c0e0b50db432c2aabde0edfc68d71":[8,1,9,0,0,2],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#ab4168039217e5ca3920d933fc3df82ab":[8,1,9,0,0,5],
-"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#afae9aaf33a25161415a8a7f207165229":[8,1,9,0,0,1],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html":[8,1,9,1],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#a3ac91f993192988b2f171d0fda79eb2c":[8,1,9,1,1],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#aa705cf7e79a21c2352b00ffe20cd295f":[8,1,9,1,0],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#aa705cf7e79a21c2352b00ffe20cd295fa3225e786433ba6df347b261b4e907e00":[8,1,9,1,0,1],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#aa705cf7e79a21c2352b00ffe20cd295fa4da202338f118b9e57137036fa2d3ca6":[8,1,9,1,0,0],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#ab55d18a0a7296fc4f6bc22eeb993e5ad":[8,1,9,1,2],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#acce6d47ad8d9d0f9d1b37bdb129eb520":[8,1,9,1,4],
-"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#ae51934333edd3a61c06a695837f30595":[8,1,9,1,3],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html":[8,1,11,0,0],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#a44e93d58ebc76240ed5fefc71cd7b157":[8,1,11,0,0,4],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#a56057819f78d9070f20423e5b3cdefa0":[8,1,11,0,0,3],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#a74f8f658773f84bd6e8b58c35dd48ad0":[8,1,11,0,0,0],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#aa62c0e0b50db432c2aabde0edfc68d71":[8,1,11,0,0,2],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#ab4168039217e5ca3920d933fc3df82ab":[8,1,11,0,0,5],
+"struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#afae9aaf33a25161415a8a7f207165229":[8,1,11,0,0,1],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html":[8,1,11,1],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#a3ac91f993192988b2f171d0fda79eb2c":[8,1,11,1,1],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#aa705cf7e79a21c2352b00ffe20cd295f":[8,1,11,1,0],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#aa705cf7e79a21c2352b00ffe20cd295fa3225e786433ba6df347b261b4e907e00":[8,1,11,1,0,1],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#aa705cf7e79a21c2352b00ffe20cd295fa4da202338f118b9e57137036fa2d3ca6":[8,1,11,1,0,0],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#ab55d18a0a7296fc4f6bc22eeb993e5ad":[8,1,11,1,2],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#acce6d47ad8d9d0f9d1b37bdb129eb520":[8,1,11,1,4],
+"struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html#ae51934333edd3a61c06a695837f30595":[8,1,11,1,3],
 "struct_v_s_t_g_u_i_1_1_c_menu_item_1_1_impl.html":[10,0,2,40,0],
 "struct_v_s_t_g_u_i_1_1_c_menu_item_1_1_impl.html#a0150fcd1c8ca13b3acca8f7b65a91187":[10,0,2,40,0,1],
 "struct_v_s_t_g_u_i_1_1_c_menu_item_1_1_impl.html#a03ddb81528dc7515a09da9177c46818e":[10,0,2,40,0,2],
@@ -183,15 +201,15 @@ var NAVTREEINDEX19 =
 "struct_v_s_t_g_u_i_1_1_c_rect.html#ae92d4020fb8937249f12cccacfe4fe21":[10,0,2,51,33],
 "struct_v_s_t_g_u_i_1_1_c_rect.html#aee213b77b49fc1c82e9a551f8d01ba46":[10,0,2,51,39],
 "struct_v_s_t_g_u_i_1_1_c_rect.html#affbf042272dd6a2757a3bfdcdbc1e7f5":[10,0,2,51,0],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html":[8,1,6,0,0],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a0150fcd1c8ca13b3acca8f7b65a91187":[8,1,6,0,0,2],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a57cba3018388e62e1f80966cc488742a":[8,1,6,0,0,6],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a81c5e282bcf7d1658736941f110cd9c3":[8,1,6,0,0,0],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a820ae9ca94c72fb06fcac9cc544ea24b":[8,1,6,0,0,5],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a8e29f556bb5489dd5297de4a80845fd8":[8,1,6,0,0,3],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a9ee682957ef18956fbe33afe9b6222fa":[8,1,6,0,0,7],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#ac8e9c3141684eca523515159ce1a44eb":[8,1,6,0,0,1],
-"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#acf0f2364370c54022f8913aab8973d7e":[8,1,6,0,0,4],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html":[8,1,8,0,0],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a0150fcd1c8ca13b3acca8f7b65a91187":[8,1,8,0,0,2],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a57cba3018388e62e1f80966cc488742a":[8,1,8,0,0,6],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a81c5e282bcf7d1658736941f110cd9c3":[8,1,8,0,0,0],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a820ae9ca94c72fb06fcac9cc544ea24b":[8,1,8,0,0,5],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a8e29f556bb5489dd5297de4a80845fd8":[8,1,8,0,0,3],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#a9ee682957ef18956fbe33afe9b6222fa":[8,1,8,0,0,7],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#ac8e9c3141684eca523515159ce1a44eb":[8,1,8,0,0,1],
+"struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html#acf0f2364370c54022f8913aab8973d7e":[8,1,8,0,0,4],
 "struct_v_s_t_g_u_i_1_1_c_slider_1_1_impl.html":[8,3,1,11,0],
 "struct_v_s_t_g_u_i_1_1_c_slider_1_1_impl.html#a11c105a0cdc3bbb4de78260c53c67e07":[8,3,1,11,0,6],
 "struct_v_s_t_g_u_i_1_1_c_slider_1_1_impl.html#a13cfd7a9dd172dfb307d5f9c12bab2c5":[8,3,1,11,0,5],
@@ -231,23 +249,5 @@ var NAVTREEINDEX19 =
 "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#aaea1e7b52a7b3a8ad5dac0528d998a92":[8,3,7,0,1],
 "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#ab138ba4dfd17c13dac1cda0bae08749d":[8,3,7,0,8],
 "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#ae2690840d7883759ccd354025e071ecf":[8,3,7,0,4],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html":[8,3,0,7,0],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a0a10a5d6efc9ffc1e4745a0092c9b42e":[8,3,0,7,0,3],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a122e5b2a4ab8dbf238d0cba30a061abf":[8,3,0,7,0,4],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a1e5cbf2f65427aafbd2afef9d8570405":[8,3,0,7,0,1],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a6113acd9a502ebc89120091d82fbe317":[8,3,0,7,0,5],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a6a9364bbd83bc1f0fc6ec2806d611974":[8,3,0,7,0,0],
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a7d82e50d9ee3c1b4c8521c83d0534b3d":[8,3,0,7,0,2],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html":[10,0,2,62],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a3bf4e88e1d267c9bf43df9600fd21ebf":[10,0,2,62,2],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a3f4eb2b0d9bff9c8b5e9b8fc760e7402":[10,0,2,62,5],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a71696a7d97aa733ed39095a3ae16abf6":[10,0,2,62,7],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a8614e2d99c33b41a30963f1428b9023d":[10,0,2,62,8],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a9998157dfdc8c56a0f69ab18e4b9e87f":[10,0,2,62,3],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a9d4ef1a90e60c51790cb8c6aa3cb0c19":[10,0,2,62,0],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#aa62ba3ca98e2a5357fe4e5d8ed287ee6":[10,0,2,62,6],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#acf9f1a2632b9ea514e3c22dd52d4f3c7":[10,0,2,62,1],
-"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#afe9c4f956d9326014240edcc9ea01115":[10,0,2,62,4],
-"struct_v_s_t_g_u_i_1_1_concat_clip.html":[10,0,2,21],
-"struct_v_s_t_g_u_i_1_1_concat_clip.html#a32006ee19de0831ee69d7e5e5df206dd":[10,0,2,21,2]
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html":[8,3,0,7,0]
 };
