@@ -1,5 +1,23 @@
 var NAVTREEINDEX20 =
 {
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a0a10a5d6efc9ffc1e4745a0092c9b42e":[8,3,0,7,0,3],
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a122e5b2a4ab8dbf238d0cba30a061abf":[8,3,0,7,0,4],
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a1e5cbf2f65427aafbd2afef9d8570405":[8,3,0,7,0,1],
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a6113acd9a502ebc89120091d82fbe317":[8,3,0,7,0,5],
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a6a9364bbd83bc1f0fc6ec2806d611974":[8,3,0,7,0,0],
+"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a7d82e50d9ee3c1b4c8521c83d0534b3d":[8,3,0,7,0,2],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html":[10,0,2,62],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a3bf4e88e1d267c9bf43df9600fd21ebf":[10,0,2,62,2],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a3f4eb2b0d9bff9c8b5e9b8fc760e7402":[10,0,2,62,5],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a71696a7d97aa733ed39095a3ae16abf6":[10,0,2,62,7],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a8614e2d99c33b41a30963f1428b9023d":[10,0,2,62,8],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a9998157dfdc8c56a0f69ab18e4b9e87f":[10,0,2,62,3],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a9d4ef1a90e60c51790cb8c6aa3cb0c19":[10,0,2,62,0],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#aa62ba3ca98e2a5357fe4e5d8ed287ee6":[10,0,2,62,6],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#acf9f1a2632b9ea514e3c22dd52d4f3c7":[10,0,2,62,1],
+"struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#afe9c4f956d9326014240edcc9ea01115":[10,0,2,62,4],
+"struct_v_s_t_g_u_i_1_1_concat_clip.html":[10,0,2,21],
+"struct_v_s_t_g_u_i_1_1_concat_clip.html#a32006ee19de0831ee69d7e5e5df206dd":[10,0,2,21,2],
 "struct_v_s_t_g_u_i_1_1_concat_clip.html#a479432127ee77145cc19d6a2d1590821":[10,0,2,21,3],
 "struct_v_s_t_g_u_i_1_1_concat_clip.html#a52a64758c07157d4f6d6b66aeffd870e":[10,0,2,21,1],
 "struct_v_s_t_g_u_i_1_1_concat_clip.html#a92e5101ea425e43528205949d0760bdb":[10,0,2,21,0],
@@ -14,19 +32,19 @@ var NAVTREEINDEX20 =
 "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#a0d49d74db4c035719c3867723cf7e779":[8,1,4,2,0,0],
 "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#ae1794d09d5075e39c1df135ed5d8664b":[8,1,4,2,0,2],
 "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#ae3c68f6750377179ad148e76693cc7d1":[8,1,4,2,0,1],
-"struct_v_s_t_g_u_i_1_1_drag_description.html":[8,1,8,4],
-"struct_v_s_t_g_u_i_1_1_drag_description.html#a24b31c0edbe02dd54d77f7b8e80e8f1f":[8,1,8,4,0],
-"struct_v_s_t_g_u_i_1_1_drag_description.html#a3c6f8002f17719fda1d32a0bc6ce8bb5":[8,1,8,4,2],
-"struct_v_s_t_g_u_i_1_1_drag_description.html#a84960eb137fdea055245f1a3b03e5ae1":[8,1,8,4,1],
-"struct_v_s_t_g_u_i_1_1_drag_description.html#ab2640626f6d929e94505e7053d709036":[8,1,8,4,3],
-"struct_v_s_t_g_u_i_1_1_drag_event_data.html":[8,1,8,6],
-"struct_v_s_t_g_u_i_1_1_drag_event_data.html#a066e7aa04f1748286418a7082c1fedee":[8,1,8,6,0],
-"struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed":[8,1,8,6,1],
-"struct_v_s_t_g_u_i_1_1_drag_event_data.html#afcfd14c96bd885b843a74fdf07114c0d":[8,1,8,6,2],
-"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html":[8,1,9,6],
-"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html#a0c2c7e80c6fde604809d49f034b84008":[8,1,9,6,2],
-"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html#aa2be501e103bad1f79e0481c80426f01":[8,1,9,6,0],
-"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html#afb7f762789096b0ce458bc7190236a05":[8,1,9,6,1],
+"struct_v_s_t_g_u_i_1_1_drag_description.html":[8,1,10,4],
+"struct_v_s_t_g_u_i_1_1_drag_description.html#a24b31c0edbe02dd54d77f7b8e80e8f1f":[8,1,10,4,0],
+"struct_v_s_t_g_u_i_1_1_drag_description.html#a3c6f8002f17719fda1d32a0bc6ce8bb5":[8,1,10,4,2],
+"struct_v_s_t_g_u_i_1_1_drag_description.html#a84960eb137fdea055245f1a3b03e5ae1":[8,1,10,4,1],
+"struct_v_s_t_g_u_i_1_1_drag_description.html#ab2640626f6d929e94505e7053d709036":[8,1,10,4,3],
+"struct_v_s_t_g_u_i_1_1_drag_event_data.html":[8,1,10,6],
+"struct_v_s_t_g_u_i_1_1_drag_event_data.html#a066e7aa04f1748286418a7082c1fedee":[8,1,10,6,0],
+"struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed":[8,1,10,6,1],
+"struct_v_s_t_g_u_i_1_1_drag_event_data.html#afcfd14c96bd885b843a74fdf07114c0d":[8,1,10,6,2],
+"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html":[8,1,11,6],
+"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html#a0c2c7e80c6fde604809d49f034b84008":[8,1,11,6,2],
+"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html#aa2be501e103bad1f79e0481c80426f01":[8,1,11,6,0],
+"struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html#afb7f762789096b0ce458bc7190236a05":[8,1,11,6,1],
 "struct_v_s_t_g_u_i_1_1_e_rect.html":[10,0,2,121],
 "struct_v_s_t_g_u_i_1_1_e_rect.html#a04c0cf6c92fc4a225e31d4bfd788648e":[10,0,2,121,0],
 "struct_v_s_t_g_u_i_1_1_e_rect.html#a0b6b4b6e3552add5576b3a5b626ab099":[10,0,2,121,2],
@@ -86,18 +104,18 @@ var NAVTREEINDEX20 =
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#ad3950c62dbda1b9f0c9a0a946ca1b7c3":[10,0,2,25,6],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#aedc2a911789abd2ee459f6ebffee0167":[10,0,2,25,7],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#af2d888dc7ccfdac4a8ad92f9c10426e8":[10,0,2,25,3],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html":[8,1,9,2,0],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a03a4f87a4ca9bc90c40e11b69e866637":[8,1,9,2,0,4],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a32a3829534c79ff7c838ff3ba7a7802c":[8,1,9,2,0,9],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a422257ca0c920b63ab00fe76f03253df":[8,1,9,2,0,5],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a4804e5e2ff7c092a0b23fd935013b48d":[8,1,9,2,0,8],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04a4da202338f118b9e57137036fa2d3ca6":[8,1,9,2,0,0],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04a60733e364a5777c127b529f133620612":[8,1,9,2,0,1],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04aaf9815af27f2215eb4759be2ea0b3d70":[8,1,9,2,0,2],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04ae4c174d5794cc681d9b19b0e8d712002":[8,1,9,2,0,3],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#acdcdb5a464d52b93b67211ed73577e3d":[8,1,9,2,0,6],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#adfa200390a57fd9d89ebd0bc4e9014d3":[8,1,9,2,0,10],
-"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#ae60a5fcf74a319efbbd09554b716105a":[8,1,9,2,0,7],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html":[8,1,11,2,0],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a03a4f87a4ca9bc90c40e11b69e866637":[8,1,11,2,0,4],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a32a3829534c79ff7c838ff3ba7a7802c":[8,1,11,2,0,9],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a422257ca0c920b63ab00fe76f03253df":[8,1,11,2,0,5],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a4804e5e2ff7c092a0b23fd935013b48d":[8,1,11,2,0,8],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04a4da202338f118b9e57137036fa2d3ca6":[8,1,11,2,0,0],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04a60733e364a5777c127b529f133620612":[8,1,11,2,0,1],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04aaf9815af27f2215eb4759be2ea0b3d70":[8,1,11,2,0,2],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#abc6126af1d45847bc59afa0aa3216b04ae4c174d5794cc681d9b19b0e8d712002":[8,1,11,2,0,3],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#acdcdb5a464d52b93b67211ed73577e3d":[8,1,11,2,0,6],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#adfa200390a57fd9d89ebd0bc4e9014d3":[8,1,11,2,0,10],
+"struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#ae60a5fcf74a319efbbd09554b716105a":[8,1,11,2,0,7],
 "struct_v_s_t_g_u_i_1_1_keyboard_event.html":[8,1,3,17],
 "struct_v_s_t_g_u_i_1_1_keyboard_event.html#a0dccc168c116f81c2fc2079f343361a9":[8,1,3,17,0],
 "struct_v_s_t_g_u_i_1_1_keyboard_event.html#a37312625fe3bfb9f5cbc48c937cd9fc7":[8,1,3,17,1],
@@ -190,22 +208,22 @@ var NAVTREEINDEX20 =
 "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#af028c074e1f093469d6718205957c253":[8,1,3,14,0],
 "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#af028c074e1f093469d6718205957c253a8e3716efd0d53882d8ed84eab83e0c68":[8,1,3,14,0,1],
 "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#af028c074e1f093469d6718205957c253ad790fb0bdc5f0bf20a1eae81e5e7b966":[8,1,3,14,0,0],
-"struct_v_s_t_g_u_i_1_1_optional.html":[8,1,7,4],
-"struct_v_s_t_g_u_i_1_1_optional.html#a08afad1dbd89a0a5a08cca3c4eae173d":[8,1,7,4,10],
-"struct_v_s_t_g_u_i_1_1_optional.html#a20f4a96fd8932e0b4d89c65f95991bc9":[8,1,7,4,14],
-"struct_v_s_t_g_u_i_1_1_optional.html#a2a9f29ac7023ba40dd75b9ba44aeafa0":[8,1,7,4,6],
-"struct_v_s_t_g_u_i_1_1_optional.html#a351c856e0ba66008ce5dcb41324e91c4":[8,1,7,4,11],
-"struct_v_s_t_g_u_i_1_1_optional.html#a4442b1b9eab40e7939e1e01cdedcb7ae":[8,1,7,4,9],
-"struct_v_s_t_g_u_i_1_1_optional.html#a5c43571450ea68b8e8adb380e8f29298":[8,1,7,4,7],
-"struct_v_s_t_g_u_i_1_1_optional.html#a69aab7db725675c63350cc385b5c82f2":[8,1,7,4,3],
-"struct_v_s_t_g_u_i_1_1_optional.html#a8abdf29c53e2d866ae58f1550b479120":[8,1,7,4,2],
-"struct_v_s_t_g_u_i_1_1_optional.html#aa385aa18f5e42db5a415c25a90f4193d":[8,1,7,4,5],
-"struct_v_s_t_g_u_i_1_1_optional.html#aae152174cdc97c454fcfc5f106f41d4d":[8,1,7,4,13],
-"struct_v_s_t_g_u_i_1_1_optional.html#abaacb7a82cc19d22b6ef512422dd860c":[8,1,7,4,0],
-"struct_v_s_t_g_u_i_1_1_optional.html#ad20897c5c8bd47f5d4005989bead0e55":[8,1,7,4,12],
-"struct_v_s_t_g_u_i_1_1_optional.html#adab0b2bee0b4120e35b86b3d0e485e63":[8,1,7,4,8],
-"struct_v_s_t_g_u_i_1_1_optional.html#af9e0e7333b5326d69a50cf183c946d4e":[8,1,7,4,4],
-"struct_v_s_t_g_u_i_1_1_optional.html#afe4a4fd73032ccb8333adc78c8d885be":[8,1,7,4,1],
+"struct_v_s_t_g_u_i_1_1_optional.html":[8,1,9,4],
+"struct_v_s_t_g_u_i_1_1_optional.html#a08afad1dbd89a0a5a08cca3c4eae173d":[8,1,9,4,10],
+"struct_v_s_t_g_u_i_1_1_optional.html#a20f4a96fd8932e0b4d89c65f95991bc9":[8,1,9,4,14],
+"struct_v_s_t_g_u_i_1_1_optional.html#a2a9f29ac7023ba40dd75b9ba44aeafa0":[8,1,9,4,6],
+"struct_v_s_t_g_u_i_1_1_optional.html#a351c856e0ba66008ce5dcb41324e91c4":[8,1,9,4,11],
+"struct_v_s_t_g_u_i_1_1_optional.html#a4442b1b9eab40e7939e1e01cdedcb7ae":[8,1,9,4,9],
+"struct_v_s_t_g_u_i_1_1_optional.html#a5c43571450ea68b8e8adb380e8f29298":[8,1,9,4,7],
+"struct_v_s_t_g_u_i_1_1_optional.html#a69aab7db725675c63350cc385b5c82f2":[8,1,9,4,3],
+"struct_v_s_t_g_u_i_1_1_optional.html#a8abdf29c53e2d866ae58f1550b479120":[8,1,9,4,2],
+"struct_v_s_t_g_u_i_1_1_optional.html#aa385aa18f5e42db5a415c25a90f4193d":[8,1,9,4,5],
+"struct_v_s_t_g_u_i_1_1_optional.html#aae152174cdc97c454fcfc5f106f41d4d":[8,1,9,4,13],
+"struct_v_s_t_g_u_i_1_1_optional.html#abaacb7a82cc19d22b6ef512422dd860c":[8,1,9,4,0],
+"struct_v_s_t_g_u_i_1_1_optional.html#ad20897c5c8bd47f5d4005989bead0e55":[8,1,9,4,12],
+"struct_v_s_t_g_u_i_1_1_optional.html#adab0b2bee0b4120e35b86b3d0e485e63":[8,1,9,4,8],
+"struct_v_s_t_g_u_i_1_1_optional.html#af9e0e7333b5326d69a50cf183c946d4e":[8,1,9,4,4],
+"struct_v_s_t_g_u_i_1_1_optional.html#afe4a4fd73032ccb8333adc78c8d885be":[8,1,9,4,1],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config.html":[8,2,17],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config.html#a191c4f2865dc62dd11051b3b26c6caf3":[8,2,17,1],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config.html#a64df22310af6cac67efa5eadf9522fe7":[8,2,17,3],
@@ -231,23 +249,5 @@ var NAVTREEINDEX20 =
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html":[8,2,19],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html#a27c923b7b97b92b9ce0c9708d891d293":[8,2,19,1],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html#a820ae9ca94c72fb06fcac9cc544ea24b":[8,2,19,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html#aef60a36d5f365618e052256cf56189c7":[8,2,19,2],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html":[8,2,5],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html#a5150c4261a4bcb40d81b8c7a8cc8f9b6":[8,2,5,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html":[10,0,2,9,1,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a1c3ad1b57347be66108fa9b491d08bd4":[10,0,2,9,1,0,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a729f5857fdc27ff281e8d333192b5124":[10,0,2,9,1,0,1],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a90e077d0b8d7b50eeb7c3ed2c98c5975":[10,0,2,9,1,0,2],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html":[8,2,22],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html#a820ae9ca94c72fb06fcac9cc544ea24b":[8,2,22,1],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html#ad40c0f0dc8adcbe5c431e6c6b921e77b":[8,2,22,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html":[8,2,29],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#a22d27b88e8c638962ede64fc0cf9ee85":[8,2,29,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#a6897c2efb803dfa7bcf2274b9e7f1c8f":[8,2,29,1],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#a738d31f7ed30f4c0c8f0467146a72a21":[8,2,29,2],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#aa2ba01b9ce98322b1207b09e13d4cae6":[8,2,29,3],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#aca0d6bfe279af0abacbe7b1c525dadbe":[8,2,29,4],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html":[10,0,2,9,5,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a0c83c7d03e9268f35430c48354a0a992":[10,0,2,9,5,0,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a5ff769fa908d21f3af50f4e162712d63":[10,0,2,9,5,0,5]
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html#aef60a36d5f365618e052256cf56189c7":[8,2,19,2]
 };
