@@ -51,16 +51,16 @@ var searchData=
   ['mode',['mode',['../struct_v_s_t_g_u_i_1_1_c_slider_base_1_1_impl.html#a58d589f725167e9138c842cc8385251d',1,'VSTGUI::CSliderBase::Impl']]],
   ['modeignoringintegralmode',['modeIgnoringIntegralMode',['../struct_v_s_t_g_u_i_1_1_c_draw_mode.html#a7d6182b5dd0ead69ef1982775d22e6d7',1,'VSTGUI::CDrawMode']]],
   ['modelbinding',['modelBinding',['../struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#a6897c2efb803dfa7bcf2274b9e7f1c8f',1,'VSTGUI::Standalone::UIDesc::Config']]],
-  ['modelbindingcallbacks',['ModelBindingCallbacks',['../class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_model_binding_callbacks.html',1,'VSTGUI::Standalone::UIDesc']]],
   ['modelbindingcallbacks',['ModelBindingCallbacks',['../class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_model_binding_callbacks.html#accd8176fb6ca80537d20c8f67a78ac5a',1,'VSTGUI::Standalone::UIDesc::ModelBindingCallbacks']]],
+  ['modelbindingcallbacks',['ModelBindingCallbacks',['../class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_model_binding_callbacks.html',1,'VSTGUI::Standalone::UIDesc']]],
   ['modelbindingcallbacksptr',['ModelBindingCallbacksPtr',['../namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html#a6471b52b34d8ecbed1cc7c60780158cb',1,'VSTGUI::Standalone::UIDesc']]],
   ['modelbindingptr',['ModelBindingPtr',['../namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html#a67ea5069d3d2713f71a645c650795927',1,'VSTGUI::Standalone::UIDesc']]],
   ['modelinear',['modeLinear',['../struct_v_s_t_g_u_i_1_1_c_knob_base_1_1_mouse_editing_state.html#a5dd378c7e92a12e38e3e08c2d91ba5db',1,'VSTGUI::CKnobBase::MouseEditingState']]],
   ['modifier',['modifier',['../struct_vst_key_code.html#ae3f31c0d691c7a842dbddc35afe1e4e5',1,'VstKeyCode']]],
   ['modifierevent',['ModifierEvent',['../struct_v_s_t_g_u_i_1_1_modifier_event.html',1,'VSTGUI']]],
   ['modifierkey',['ModifierKey',['../group__new__in__4__11.html#ga51910458d0a923b29f1694654d8eb00a',1,'VSTGUI']]],
+  ['modifiers',['modifiers',['../struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::DragEventData::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::ModifierEvent::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57',1,'VSTGUI::Modifiers::Modifiers()=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d',1,'VSTGUI::Modifiers::Modifiers(const Modifiers &amp;)=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f',1,'VSTGUI::Modifiers::Modifiers(ModifierKey modifier)']]],
   ['modifiers',['Modifiers',['../struct_v_s_t_g_u_i_1_1_modifiers.html',1,'VSTGUI']]],
-  ['modifiers',['Modifiers',['../struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57',1,'VSTGUI::Modifiers::Modifiers()=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d',1,'VSTGUI::Modifiers::Modifiers(const Modifiers &amp;)=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f',1,'VSTGUI::Modifiers::Modifiers(ModifierKey modifier)'],['../struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::DragEventData::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::ModifierEvent::modifiers()']]],
   ['mousebutton',['MouseButton',['../group__new__in__4__11.html#gab8d93bdfbb0fd7ae143bbfda46bf38bc',1,'VSTGUI']]],
   ['mousecancelevent',['MouseCancelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html',1,'VSTGUI']]],
   ['mousecancelevent',['MouseCancelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html#a972937b504a1b35085f6e5204f18e638',1,'VSTGUI::MouseCancelEvent']]],
@@ -89,8 +89,8 @@ var searchData=
   ['mouseupevent',['MouseUpEvent',['../struct_v_s_t_g_u_i_1_1_mouse_up_event.html#a6996b1c242ad6835a95aaed856897120',1,'VSTGUI::MouseUpEvent::MouseUpEvent()'],['../struct_v_s_t_g_u_i_1_1_mouse_up_event.html#a51bad606644b76eb8f914432b1475431',1,'VSTGUI::MouseUpEvent::MouseUpEvent(const CPoint &amp;pos, MouseEventButtonState buttons)']]],
   ['mouseupevent',['MouseUpEvent',['../struct_v_s_t_g_u_i_1_1_mouse_up_event.html',1,'VSTGUI']]],
   ['mouseviews',['mouseViews',['../struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aa3d0cd46ab50a61ee8dd77f85f6ebea0',1,'VSTGUI::CFrame::Impl']]],
-  ['mousewheelevent',['MouseWheelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html',1,'VSTGUI']]],
   ['mousewheelevent',['MouseWheelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#a1c0d2e8544fc3d194f796bb9e73a7b88',1,'VSTGUI::MouseWheelEvent']]],
+  ['mousewheelevent',['MouseWheelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html',1,'VSTGUI']]],
   ['movablebywindowbackground',['movableByWindowBackground',['../struct_v_s_t_g_u_i_1_1_standalone_1_1_window_style.html#a3178c503bec1093e791774bddb5c0267',1,'VSTGUI::Standalone::WindowStyle']]],
   ['movedfunc',['movedFunc',['../class_v_s_t_g_u_i_1_1_drag_callback_functions.html#aaf5a237bf1ccf958c49ad55d70f89713',1,'VSTGUI::DragCallbackFunctions']]],
   ['moveoldfile',['moveOldFile',['../namespace_v_s_t_g_u_i.html#a1cf9ef372f63c82d34330fb1c29001c1',1,'VSTGUI']]],
@@ -100,6 +100,14 @@ var searchData=
   ['moviebuttoncreator',['MovieButtonCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_movie_button_creator.html',1,'VSTGUI::UIViewCreator']]],
   ['moviebuttoncreator',['MovieButtonCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_movie_button_creator.html#a7034deb1662ebacca3d04a411779cefc',1,'VSTGUI::UIViewCreator::MovieButtonCreator']]],
   ['multibitmapcontrolcreator',['MultiBitmapControlCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_multi_bitmap_control_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['multiframebitmapview',['MultiFrameBitmapView',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20canimknob_20_3e',['MultiFrameBitmapView&lt; CAnimKnob &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20cautoanimation_20_3e',['MultiFrameBitmapView&lt; CAutoAnimation &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20ckickbutton_20_3e',['MultiFrameBitmapView&lt; CKickButton &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20cmoviebitmap_20_3e',['MultiFrameBitmapView&lt; CMovieBitmap &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20cmoviebutton_20_3e',['MultiFrameBitmapView&lt; CMovieButton &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20crockerswitch_20_3e',['MultiFrameBitmapView&lt; CRockerSwitch &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
+  ['multiframebitmapview_3c_20cswitchbase_20_3e',['MultiFrameBitmapView&lt; CSwitchBase &gt;',['../class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html',1,'VSTGUI']]],
   ['multilinetextlabelcreator',['MultiLineTextLabelCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_multi_line_text_label_creator.html#a02802f22f99abc7edf270c892da5b943',1,'VSTGUI::UIViewCreator::MultiLineTextLabelCreator']]],
   ['multilinetextlabelcreator',['MultiLineTextLabelCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_multi_line_text_label_creator.html',1,'VSTGUI::UIViewCreator']]],
   ['miscellaneous',['Miscellaneous',['../page_misc.html',1,'']]]
