@@ -16,7 +16,7 @@ var searchData=
   ['tostring',['toString',['../struct_v_s_t_g_u_i_1_1_c_color.html#a0f028164d33e42bbf93c326ade09c6f5',1,'VSTGUI::CColor::toString()'],['../namespace_v_s_t_g_u_i.html#a27a9880d7e634c8ffcaaabf990d68e32',1,'VSTGUI::toString()']]],
   ['tovstkeycode',['toVstKeyCode',['../namespace_v_s_t_g_u_i.html#a9ff61fbaceee2ad20764752ba0e2aa6c',1,'VSTGUI']]],
   ['tovstvirtualkey',['toVstVirtualKey',['../group__new__in__4__11.html#ga010ad00fd4fa3deaa934b01b4a4e1ba1',1,'VSTGUI']]],
-  ['transform',['transform',['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#af5b80ac47e3d74fe4cf0ca4d75f2e6c3',1,'VSTGUI::CGraphicsTransform::transform(CCoord &amp;x, CCoord &amp;y) const '],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a4190cc2fafabe680a032e979102a02aa',1,'VSTGUI::CGraphicsTransform::transform(CCoord &amp;left, CCoord &amp;right, CCoord &amp;top, CCoord &amp;bottom) const '],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#ad9ef1f20b460146b76b62b7e2642f2bf',1,'VSTGUI::CGraphicsTransform::transform(CPoint &amp;p) const '],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a27d1065944606acbc2566f76407e0fa8',1,'VSTGUI::CGraphicsTransform::transform(CRect &amp;r) const '],['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_transform.html#a34a14c210c9849c7ad7e3828727bbb8f',1,'VSTGUI::CDrawContext::Transform::Transform()']]],
+  ['transform',['Transform',['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_transform.html#a34a14c210c9849c7ad7e3828727bbb8f',1,'VSTGUI::CDrawContext::Transform::Transform()'],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#af5b80ac47e3d74fe4cf0ca4d75f2e6c3',1,'VSTGUI::CGraphicsTransform::transform(CCoord &amp;x, CCoord &amp;y) const '],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a4190cc2fafabe680a032e979102a02aa',1,'VSTGUI::CGraphicsTransform::transform(CCoord &amp;left, CCoord &amp;right, CCoord &amp;top, CCoord &amp;bottom) const '],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#ad9ef1f20b460146b76b62b7e2642f2bf',1,'VSTGUI::CGraphicsTransform::transform(CPoint &amp;p) const '],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a27d1065944606acbc2566f76407e0fa8',1,'VSTGUI::CGraphicsTransform::transform(CRect &amp;r) const ']]],
   ['translate',['translate',['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a5235ece1301b85093760b1bd924c754d',1,'VSTGUI::CGraphicsTransform::translate(double x, double y)'],['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a95c121da9f2c59a74a2c45029ee5e6ff',1,'VSTGUI::CGraphicsTransform::translate(const CPoint &amp;p)']]],
   ['translatetoglobal',['translateToGlobal',['../class_v_s_t_g_u_i_1_1_c_view.html#a6b3bbeca5fa499a2c0313e95a78f481f',1,'VSTGUI::CView::translateToGlobal(T &amp;t, bool ignoreFrame=false) const '],['../class_v_s_t_g_u_i_1_1_c_view.html#a3b1074b10e095be747ae2f959b62c2fa',1,'VSTGUI::CView::translateToGlobal(const T &amp;t, bool ignoreFrame=false) const ']]],
   ['translatetolocal',['translateToLocal',['../class_v_s_t_g_u_i_1_1_c_view.html#a61c535ea19b6147622cf2c52bc7c5e4d',1,'VSTGUI::CView::translateToLocal(T &amp;t, bool ignoreFrame=false) const '],['../class_v_s_t_g_u_i_1_1_c_view.html#aa6e8f07f05547d3f45d25bba60019acd',1,'VSTGUI::CView::translateToLocal(const T &amp;t, bool ignoreFrame=false) const ']]],
