@@ -11,6 +11,8 @@ var group__speakerArrangements =
     [ "hasLfe", "group__speakerArrangements.html#gae80135ca5a48c012ae56eba60aed8ba7", null ],
     [ "is3D", "group__speakerArrangements.html#gae5b25533bf821c6470e9d5a8d37b2f08", null ],
     [ "isAmbisonics", "group__speakerArrangements.html#ga1eb079a06c32ed8dfe5640d1ea129beb", null ],
+    [ "convertSpeaker_Ambi_1234Order_to_Ambi567Order", "group__speakerArrangements.html#ga3e1ccb637aac3918a31d5b061bcaabe4", null ],
+    [ "convertSpeaker_Ambi_567Order_to_Ambi1234Order", "group__speakerArrangements.html#gae74e19a6a7653396d1c0e91ff85de6cb", null ],
     [ "getSpeakerArrangementFromString", "group__speakerArrangements.html#gae59865c6f6e439696b408a8e3a35fb67", null ],
     [ "getSpeakerArrangementString", "group__speakerArrangements.html#ga8f3040f601ddc82b7ff76bd0ac66b32b", null ],
     [ "getSpeakerShortName", "group__speakerArrangements.html#gaea8fb2e63d819b83b1811645b5f5c0a0", null ],
@@ -51,6 +53,15 @@ var group__speakerArrangements =
     [ "kSpeakerACN13", "group__speakerArrangements.html#ga1604729c414047881e20341108871354", null ],
     [ "kSpeakerACN14", "group__speakerArrangements.html#ga3633546c0ee46e3c70c52843faf722e6", null ],
     [ "kSpeakerACN15", "group__speakerArrangements.html#gae7a63dcd11e24560783142099359dca4", null ],
+    [ "kSpeakerACN16", "group__speakerArrangements.html#gaf6a1083557b66bb33ab237b2894aa0fa", null ],
+    [ "kSpeakerACN17", "group__speakerArrangements.html#gafd02153e1c7df908d78dba3344573ecb", null ],
+    [ "kSpeakerACN18", "group__speakerArrangements.html#ga91318c6519398caaa67b5f1656167936", null ],
+    [ "kSpeakerACN19", "group__speakerArrangements.html#ga3531cf9980f8fbeb289280f70cb82eb0", null ],
+    [ "kSpeakerACN20", "group__speakerArrangements.html#ga34c39373e8684ea0bdd623206d23f92a", null ],
+    [ "kSpeakerACN21", "group__speakerArrangements.html#ga59a627e4f770f658147db9ae99012a86", null ],
+    [ "kSpeakerACN22", "group__speakerArrangements.html#ga1f29f3c176afccd1a3b9572cbc58ded3", null ],
+    [ "kSpeakerACN23", "group__speakerArrangements.html#ga979239f98d73f46be915cf0d2600c8e6", null ],
+    [ "kSpeakerACN24", "group__speakerArrangements.html#ga41826ce2877ff6e8fc93c8d4aa85647e", null ],
     [ "kSpeakerTsl", "group__speakerArrangements.html#gae27ef071e8ea85bdb2d5e35cb72c4313", null ],
     [ "kSpeakerTsr", "group__speakerArrangements.html#gac5f061a31de54df1c627e9ec947ac442", null ],
     [ "kSpeakerLcs", "group__speakerArrangements.html#gac91567b9c8119eb78d51f6cc398bd97f", null ],
@@ -110,6 +121,10 @@ var group__speakerArrangements =
     [ "kAmbi1stOrderACN", "group__speakerArrangements.html#ga02d21f6bfee6423fceb6a3695954c33b", null ],
     [ "kAmbi2cdOrderACN", "group__speakerArrangements.html#ga6117e1aa058a519559fbea82adb0aa69", null ],
     [ "kAmbi3rdOrderACN", "group__speakerArrangements.html#ga1b19ef3d9cbdfb96c008f4586b186997", null ],
+    [ "kAmbi4thOrderACN", "group__speakerArrangements.html#gaa7128399bc94194318d05a42a656b6c3", null ],
+    [ "kAmbi5thOrderACN", "group__speakerArrangements.html#ga75c0d3966f966fdc114f3743693f6661", null ],
+    [ "kAmbi6thOrderACN", "group__speakerArrangements.html#gacb03caa7a584d5c6e2c1dba585e17388", null ],
+    [ "kAmbi7thOrderACN", "group__speakerArrangements.html#gaba508607de22c17a41421f3e012e9c6d", null ],
     [ "k80Cube", "group__speakerArrangements.html#ga44ee3dd3579cc26082915d76a28be70f", null ],
     [ "k40_4", "group__speakerArrangements.html#gae473d3c439f65d8948d6c2889be93490", null ],
     [ "k71CineTopCenter", "group__speakerArrangements.html#ga9c79cded90ddc1a1e366e1fbf4315334", null ],
@@ -120,7 +135,10 @@ var group__speakerArrangements =
     [ "k71CineFrontHigh", "group__speakerArrangements.html#ga8e2c48c3830b09da02e7bb123f5916bd", null ],
     [ "k71MPEG3D", "group__speakerArrangements.html#gaf21f025b23bb45133395657787f88a13", null ],
     [ "k51_2", "group__speakerArrangements.html#ga915a918d766f639dfc9f15c8a8bd9ade", null ],
+    [ "k70CineSideHigh", "group__speakerArrangements.html#ga7538b09e2e8f95cd13f370f21de7f9f6", null ],
+    [ "k50_2_TS", "group__speakerArrangements.html#gad29f5880932646a417c0ea712454874c", null ],
     [ "k71CineSideHigh", "group__speakerArrangements.html#ga300b4574ad12477ff99286519b754dfe", null ],
+    [ "k51_2_TS", "group__speakerArrangements.html#gac7c590bd9642823b634c33a5fa3d6cfd", null ],
     [ "k81MPEG3D", "group__speakerArrangements.html#ga1d7c7f813f01cd3f4478ecc81e46e82c", null ],
     [ "k41_4_1", "group__speakerArrangements.html#ga9bce1aee5d88c3554f787f3a4a44e7ff", null ],
     [ "k90", "group__speakerArrangements.html#gab04f1f4652d14e277671a0b62a8e8373", null ],
@@ -166,6 +184,16 @@ var group__speakerArrangements =
     [ "k102_9_3", "group__speakerArrangements.html#gaa6fae1c3c9c0603d95b8fec74a145309", null ],
     [ "k50_5_3", "group__speakerArrangements.html#gaddebe89c64428865b798a9992534b087", null ],
     [ "k51_5_3", "group__speakerArrangements.html#ga52ca6a659ccabd38af3e0e5b3af932d2", null ],
+    [ "k50_2_2", "group__speakerArrangements.html#ga447cbeb4a66d7a12f6c36240b666331a", null ],
+    [ "k50_4_2", "group__speakerArrangements.html#ga22796d2f7f109bde16a525429c8194af", null ],
+    [ "k70_4_2", "group__speakerArrangements.html#ga419904483b34cd1d809100f7388d50b7", null ],
+    [ "k50_5_Sony", "group__speakerArrangements.html#gadb8c4b83f39868ff4da93be72a3dfef0", null ],
+    [ "k40_2_2", "group__speakerArrangements.html#gabd12a0facfe37226a9f5601ed1b5de4d", null ],
+    [ "k40_4_2", "group__speakerArrangements.html#gace185a0a2ef646fc3dd9b26777acc25d", null ],
+    [ "k50_3_2", "group__speakerArrangements.html#ga1c30f7ea8d0b380ec954fd35e1cbc33e", null ],
+    [ "k30_5_2", "group__speakerArrangements.html#ga8ace2cc7e8e56351d3df5f95bac9ff8f", null ],
+    [ "k40_4_4", "group__speakerArrangements.html#ga5cd8e94e229c89d617dfea91d364c9e7", null ],
+    [ "k50_4_4", "group__speakerArrangements.html#gacafff17c0c21e0030c6bb0cce8b72576", null ],
     [ "kStringEmpty", "group__speakerArrangements.html#ga38c557da6a4db5884d2d688c30cc5553", null ],
     [ "kStringMono", "group__speakerArrangements.html#gacc3c2f0d3a1a7cefebcd21afcaff0a33", null ],
     [ "kStringStereo", "group__speakerArrangements.html#gaa8801dd84fb2f8566448a99c418d1185", null ],
@@ -202,22 +230,23 @@ var group__speakerArrangements =
     [ "kString71MusicOld", "group__speakerArrangements.html#gaa259ec989476ec18dd30dbbe9edaa6a8", null ],
     [ "kString71CineTopCenter", "group__speakerArrangements.html#ga6f792b0962f42ec4f133cb64de72d31e", null ],
     [ "kString71CineCenterHigh", "group__speakerArrangements.html#gabbfecee6091fbab1bbd2d3e073b86f5d", null ],
-    [ "kString71CineFrontHigh", "group__speakerArrangements.html#ga1447af9f22f48e0d039569b10a17aec2", null ],
-    [ "kString70CineFrontHigh", "group__speakerArrangements.html#gabbd6ae53059e6e707c49d3d16261a047", null ],
-    [ "kString71CineSideHigh", "group__speakerArrangements.html#gad8deb48b287d7520c56e233f8020243c", null ],
     [ "kString71CineFullRear", "group__speakerArrangements.html#gab78c124e88ad66fcd06aa09f3871320e", null ],
+    [ "kString51_2", "group__speakerArrangements.html#gaa4edb550a1fa7674cbd3d4f36057739e", null ],
+    [ "kString50_2", "group__speakerArrangements.html#ga541d217c8f043728ff06915e44c8bdbd", null ],
+    [ "kString50_2TopSide", "group__speakerArrangements.html#ga230b03c83c3ad137460b4ab78fdede4a", null ],
+    [ "kString51_2TopSide", "group__speakerArrangements.html#gaa642ca60e40a5c4cfb45a22ffc13d41d", null ],
     [ "kString71Proximity", "group__speakerArrangements.html#ga30a288eb79dfa6b08afb569234e831d2", null ],
     [ "kString80Cine", "group__speakerArrangements.html#gae7259d85e37e87f3734e0645a890312b", null ],
     [ "kString80Music", "group__speakerArrangements.html#ga35c11fa95eb4ed5340307b725c53180d", null ],
-    [ "kString80Cube", "group__speakerArrangements.html#gae9dde9509cd3485e2976e44ec37e2491", null ],
+    [ "kString40_4", "group__speakerArrangements.html#ga7862d38f234a211df2a6273bbce64000", null ],
     [ "kString81Cine", "group__speakerArrangements.html#gaf949196ba6ad50b12f2522524ae2079a", null ],
     [ "kString81Music", "group__speakerArrangements.html#ga301aef980be40689f6a32d2f2ea5990d", null ],
     [ "kString90Cine", "group__speakerArrangements.html#gaa72e158f204f9834347b1d811f0e1e1c", null ],
     [ "kString91Cine", "group__speakerArrangements.html#gac31faedafc0d6ef570cb6b5098b189b2", null ],
     [ "kString100Cine", "group__speakerArrangements.html#ga42ee84421893fe9759b400d0bd3becaf", null ],
     [ "kString101Cine", "group__speakerArrangements.html#ga4623d9c5afc0883aa25409a89fc4b01c", null ],
-    [ "kString102", "group__speakerArrangements.html#gab514f5233daf9f0d39022eaf6bc3ee39", null ],
-    [ "kString122", "group__speakerArrangements.html#gac4932606e4ac1473f0da939a03172e4a", null ],
+    [ "kString52_5", "group__speakerArrangements.html#ga2abe9ebdaff5cae2f2581a558cb3eb02", null ],
+    [ "kString72_5", "group__speakerArrangements.html#ga57a18ac1a2f5453752d9350c6b2795d3", null ],
     [ "kString50_4", "group__speakerArrangements.html#gacfc39ea40d9b3ee2c64ee332aadf9dc5", null ],
     [ "kString51_4", "group__speakerArrangements.html#ga3087980012d3e5dee03f977677790623", null ],
     [ "kString50_4_1", "group__speakerArrangements.html#gaa5253e1dbbc9ed637733b166da5a7304", null ],
@@ -234,21 +263,35 @@ var group__speakerArrangements =
     [ "kString91_4", "group__speakerArrangements.html#ga3b0b6d1ed6af07daa84a016f9a594d59", null ],
     [ "kString90_6", "group__speakerArrangements.html#gaa1fe4d708fa32e7b1ddeb892fa073509", null ],
     [ "kString91_6", "group__speakerArrangements.html#gab8ec511d08a024efcfc54258ddaf48cf", null ],
-    [ "kString100", "group__speakerArrangements.html#ga230095c9378b6f8cac9f14120786423f", null ],
-    [ "kString101", "group__speakerArrangements.html#gab2d2b7fc9562b4aec27425a1f46e6b5b", null ],
-    [ "kString110", "group__speakerArrangements.html#ga403a29103a9bfa626785cfc61bcce1d3", null ],
-    [ "kString111", "group__speakerArrangements.html#ga05776481c1feeb8db0bd8a8f9fd7bcdc", null ],
+    [ "kString50_5", "group__speakerArrangements.html#ga78e757a9d10fe70b7ee5a16ddd02cd1e", null ],
+    [ "kString51_5", "group__speakerArrangements.html#ga6ad5cb522b313a38c2134c7706b73027", null ],
+    [ "kString50_6", "group__speakerArrangements.html#gad826493413cb2611f94658e9ed2c2520", null ],
+    [ "kString51_6", "group__speakerArrangements.html#gad41abd22120392163e10a8699f174346", null ],
     [ "kString130", "group__speakerArrangements.html#gac7d25b1cc65c51e76c225ae50c4116ba", null ],
     [ "kString131", "group__speakerArrangements.html#gaf610b7be568618c5d5c3aa20d4cf2ecb", null ],
-    [ "kString81MPEG", "group__speakerArrangements.html#ga86ba0d184e2fd6b86e876d5a7343cc5c", null ],
-    [ "kString140", "group__speakerArrangements.html#ga030afab00e1f4278f53911d4a89a7b98", null ],
-    [ "kString222", "group__speakerArrangements.html#gaad33c8ed818e1d8f2a30195dadf50af9", null ],
+    [ "kString41_4_1", "group__speakerArrangements.html#ga2b7412e5a07fbbce4e641a8fa7b81001", null ],
+    [ "kString60_4_4", "group__speakerArrangements.html#ga7c9500be12cf3867ab2009b13a490f8f", null ],
     [ "kString220", "group__speakerArrangements.html#gaebcce0418f6b0300b6f862766f7f58e2", null ],
+    [ "kString222", "group__speakerArrangements.html#gaad33c8ed818e1d8f2a30195dadf50af9", null ],
     [ "kString50_5_3", "group__speakerArrangements.html#gaf5367c0d3c1ca0a638ecb2dc5198d5a1", null ],
     [ "kString51_5_3", "group__speakerArrangements.html#gabfd1ce52185e9de239a2d86cdfaa96ae", null ],
+    [ "kString50_2_2", "group__speakerArrangements.html#ga7e8fcff06d6336d9e074bb52126906c1", null ],
+    [ "kString50_4_2", "group__speakerArrangements.html#gab315be1e08a3fd8881483cb595d04977", null ],
+    [ "kString70_4_2", "group__speakerArrangements.html#ga8ef7ca32e5928ef168cffbfdf5eb74ec", null ],
+    [ "kString50_5_Sony", "group__speakerArrangements.html#gae67ecf106b1633e3bab42ce580dd8b9f", null ],
+    [ "kString40_2_2", "group__speakerArrangements.html#ga724f21f7494bf592885a7637069e8b35", null ],
+    [ "kString40_4_2", "group__speakerArrangements.html#ga5a004301eeca0b6240d2b13f804c7bff", null ],
+    [ "kString50_3_2", "group__speakerArrangements.html#ga2f656b124363f1656327bf5fb9e7dc48", null ],
+    [ "kString30_5_2", "group__speakerArrangements.html#ga55e31b6eaebd31f8c42e2e5daaf6443a", null ],
+    [ "kString40_4_4", "group__speakerArrangements.html#gab9474808a2720d77eb38733cb2e5e831", null ],
+    [ "kString50_4_4", "group__speakerArrangements.html#ga3151e2974547b528528e913542dd5292", null ],
     [ "kStringAmbi1stOrder", "group__speakerArrangements.html#gae989a0ed646d1b90e700b6599b87e9c5", null ],
     [ "kStringAmbi2cdOrder", "group__speakerArrangements.html#ga57421a0b5dd2faacfc03c8b4df47c626", null ],
     [ "kStringAmbi3rdOrder", "group__speakerArrangements.html#gab530c1e2f6dfd766cfb9f1b4f11b6ddf", null ],
+    [ "kStringAmbi4thOrder", "group__speakerArrangements.html#ga24d4f4886be5ec7ac6fa441212f9b402", null ],
+    [ "kStringAmbi5thOrder", "group__speakerArrangements.html#gaf80df1bbb9f317dd4c11ac891a2f8f40", null ],
+    [ "kStringAmbi6thOrder", "group__speakerArrangements.html#ga1d0d1ec6684406ef2ca93eb7bd921bb3", null ],
+    [ "kStringAmbi7thOrder", "group__speakerArrangements.html#gaeae5f636bab30a1fc18cb36210b23b56", null ],
     [ "kStringMonoS", "group__speakerArrangements.html#ga646cd09e52190d60f2d4ca83faf915aa", null ],
     [ "kStringStereoS", "group__speakerArrangements.html#ga54144ab0e1dd2babcf5e720950cf7e24", null ],
     [ "kStringStereoRS", "group__speakerArrangements.html#ga63f3673e0a9ad13c3788b583d4fac61b", null ],
@@ -282,13 +325,14 @@ var group__speakerArrangements =
     [ "kString80MusicS", "group__speakerArrangements.html#ga8204788aa5b2fce1730c157dc8a9239f", null ],
     [ "kString81CineS", "group__speakerArrangements.html#gafe30ad0333248d38dfd6a162879a97a6", null ],
     [ "kString81MusicS", "group__speakerArrangements.html#ga5b7279077b689fa26044fc2520a413c7", null ],
-    [ "kString80CubeS", "group__speakerArrangements.html#gab5aedcc126b998d57c67be78255cd52b", null ],
+    [ "kString40_4S", "group__speakerArrangements.html#ga4b1241bc660c2cd6fe752e2f3a1d6de7", null ],
     [ "kString71CineTopCenterS", "group__speakerArrangements.html#ga006f007337addc5c126777bc9e9b774d", null ],
     [ "kString71CineCenterHighS", "group__speakerArrangements.html#gaf0c13b30d128debc8f8976927a321f48", null ],
-    [ "kString71CineFrontHighS", "group__speakerArrangements.html#ga19c9b28dd806c4a7cf532e33c4db7d1d", null ],
-    [ "kString70CineFrontHighS", "group__speakerArrangements.html#gaf42184eb733b64be0518a0a1d783e0c7", null ],
-    [ "kString71CineSideHighS", "group__speakerArrangements.html#ga708f2bb3ba7a3f624acf291960ca7788", null ],
     [ "kString71CineFullRearS", "group__speakerArrangements.html#ga5e313aadeb060bc3dc88d17ca2e81a06", null ],
+    [ "kString50_2S", "group__speakerArrangements.html#ga0a881b193fdb5ee3949d4da3501cf4c5", null ],
+    [ "kString51_2S", "group__speakerArrangements.html#ga9544be5659ac804df18bc1ac524e7305", null ],
+    [ "kString50_2TopSideS", "group__speakerArrangements.html#ga80f213e5708edd67d2d834a51d247e68", null ],
+    [ "kString51_2TopSideS", "group__speakerArrangements.html#gaca11b7e3831e00dd7b5828111675411a", null ],
     [ "kString71ProximityS", "group__speakerArrangements.html#ga86fc6ff2265855e22d3573786e05af2d", null ],
     [ "kString90CineS", "group__speakerArrangements.html#ga4a24b9cdab9b5ed5af4ae28cbe8f7205", null ],
     [ "kString91CineS", "group__speakerArrangements.html#gabebe500b3d27127ae844c7fcabb854f0", null ],
@@ -310,21 +354,35 @@ var group__speakerArrangements =
     [ "kString91_4S", "group__speakerArrangements.html#ga1b17445201a92bee4c23dd16e5cd1728", null ],
     [ "kString90_6S", "group__speakerArrangements.html#gac89dcac8a9acb594a3e406cc5241d650", null ],
     [ "kString91_6S", "group__speakerArrangements.html#gaf0b16e15ff6616a3e481b879d3b4c53f", null ],
-    [ "kString100S", "group__speakerArrangements.html#gaec0be9229bbb0796d8d1c69e059e7501", null ],
-    [ "kString101S", "group__speakerArrangements.html#ga5c88990128aeaf6e70cf777e2e2e07f0", null ],
-    [ "kString110S", "group__speakerArrangements.html#gacd74a4610c5894723966b586ff76780b", null ],
-    [ "kString111S", "group__speakerArrangements.html#ga6520dd17a30ba116ac2877b28a1b8cc9", null ],
+    [ "kString50_5S", "group__speakerArrangements.html#ga597dea323dcd6ebf7a8f79e222744396", null ],
+    [ "kString51_5S", "group__speakerArrangements.html#ga693724048ed9aa6572030b22a0c722d5", null ],
+    [ "kString50_5_SonyS", "group__speakerArrangements.html#ga7697d22e6e22fa8c6948bd482737ce62", null ],
+    [ "kString50_6S", "group__speakerArrangements.html#gac97a088b45e2fde1967424d9b81fedd3", null ],
+    [ "kString51_6S", "group__speakerArrangements.html#ga8d36f86e550d1e385d7df0f1b95fe644", null ],
     [ "kString130S", "group__speakerArrangements.html#gaccdab4f0e651d4c1b0b850e6c8edb9f4", null ],
     [ "kString131S", "group__speakerArrangements.html#ga9cdfa2ff878225396509ca7b25af7f1f", null ],
-    [ "kString102S", "group__speakerArrangements.html#ga31de54f5e618a467f94a579550328644", null ],
-    [ "kString122S", "group__speakerArrangements.html#ga800e2e69c905b5feaeda81ac24b3f653", null ],
-    [ "kString81MPEGS", "group__speakerArrangements.html#ga78b0189e39c80c0bf5cec0ddcce73cf9", null ],
-    [ "kString140S", "group__speakerArrangements.html#ga426116f26f987c030cf2bc70302aa219", null ],
-    [ "kString222S", "group__speakerArrangements.html#gab442cbf6e2447ea3a762e0c9c891d274", null ],
-    [ "kString220S", "group__speakerArrangements.html#ga9df1f69930cf3ab747d645b40ba073c1", null ],
+    [ "kString52_5S", "group__speakerArrangements.html#gab885c9cdd40c853e3fa0d814cbe405fc", null ],
+    [ "kString72_5S", "group__speakerArrangements.html#gad91914c14ceb3f46c9b03dcba94c4da8", null ],
+    [ "kString41_4_1S", "group__speakerArrangements.html#ga95a8ec3f36de03bb6b9f3f1be339f889", null ],
+    [ "kString30_5_2S", "group__speakerArrangements.html#ga0049a81a50306a41abd45f0871e13173", null ],
+    [ "kString40_2_2S", "group__speakerArrangements.html#ga2211a95b3ce1e534c1da0ad1824c4018", null ],
+    [ "kString40_4_2S", "group__speakerArrangements.html#ga8091e05a3cda7c9ce2c16b0e819f7a01", null ],
+    [ "kString40_4_4S", "group__speakerArrangements.html#gaebd0216ab437c17333f06b23acc1cb17", null ],
+    [ "kString50_4_4S", "group__speakerArrangements.html#ga2990e1e187ac62b502407cad4fea5ae7", null ],
+    [ "kString60_4_4S", "group__speakerArrangements.html#ga272cd10cad55c182440769f24c656cc0", null ],
     [ "kString50_5_3S", "group__speakerArrangements.html#ga36a920fcf904e74af45153417e6bda20", null ],
     [ "kString51_5_3S", "group__speakerArrangements.html#ga1f2886d3047f9f7b5fd699b1d9fa6a79", null ],
+    [ "kString50_2_2S", "group__speakerArrangements.html#ga834a0174a7e6edd7f975bc5aebabd8c2", null ],
+    [ "kString50_3_2S", "group__speakerArrangements.html#gad7fad738b417a8446da419af519f64de", null ],
+    [ "kString50_4_2S", "group__speakerArrangements.html#ga4a84febf8ecee1a6ba6c0a8786d378c3", null ],
+    [ "kString70_4_2S", "group__speakerArrangements.html#ga6ad6a86612666400c64e041499a0f0b4", null ],
+    [ "kString222S", "group__speakerArrangements.html#gab442cbf6e2447ea3a762e0c9c891d274", null ],
+    [ "kString220S", "group__speakerArrangements.html#ga9df1f69930cf3ab747d645b40ba073c1", null ],
     [ "kStringAmbi1stOrderS", "group__speakerArrangements.html#ga319dbf573206d0bb1a8b77e7f476548d", null ],
     [ "kStringAmbi2cdOrderS", "group__speakerArrangements.html#ga81cbc11f839866ed8a91dc903e5a6d97", null ],
-    [ "kStringAmbi3rdOrderS", "group__speakerArrangements.html#gab2317fa07e1e7ee2cfce204a07945c40", null ]
+    [ "kStringAmbi3rdOrderS", "group__speakerArrangements.html#gab2317fa07e1e7ee2cfce204a07945c40", null ],
+    [ "kStringAmbi4thOrderS", "group__speakerArrangements.html#ga839832f21fa2e52200f91f09ad492209", null ],
+    [ "kStringAmbi5thOrderS", "group__speakerArrangements.html#gaadef9295f857718379440bb7ad4d3382", null ],
+    [ "kStringAmbi6thOrderS", "group__speakerArrangements.html#ga7a433d89eecd7b1c0bde77f0741a398b", null ],
+    [ "kStringAmbi7thOrderS", "group__speakerArrangements.html#gaf509dd6c5d2edb6286c52038f69b8c7e", null ]
 ];
\ No newline at end of file
