@@ -1,5 +1,64 @@
 var NAVTREEINDEX4 =
 {
+"group__speakerArrangements.html#gae74e19a6a7653396d1c0e91ff85de6cb":[0,8,12],
+"group__speakerArrangements.html#gae74ef8bbc9cc9012e28c09893fc80b6e":[0,8,27],
+"group__speakerArrangements.html#gae771dcd8cf33e293b56b78ea7693544c":[0,8,23],
+"group__speakerArrangements.html#gae7a63dcd11e24560783142099359dca4":[0,8,52],
+"group__speakerArrangements.html#gae80135ca5a48c012ae56eba60aed8ba7":[0,8,8],
+"group__speakerArrangements.html#gae989a0ed646d1b90e700b6599b87e9c5":[0,8,285],
+"group__speakerArrangements.html#gaea0ef00845b9443a18b63572e3c6338a":[0,8,32],
+"group__speakerArrangements.html#gaea8fb2e63d819b83b1811645b5f5c0a0":[0,8,15],
+"group__speakerArrangements.html#gaeae5f636bab30a1fc18cb36210b23b56":[0,8,291],
+"group__speakerArrangements.html#gaebcce0418f6b0300b6f862766f7f58e2":[0,8,271],
+"group__speakerArrangements.html#gaebd0216ab437c17333f06b23acc1cb17":[0,8,367],
+"group__speakerArrangements.html#gaec8cf18e8bfd88584375e66b67fde24e":[0,8,320],
+"group__speakerArrangements.html#gaeed20d0347a2ea4100a9b58990c5bcc1":[0,8,252],
+"group__speakerArrangements.html#gaf0b16e15ff6616a3e481b879d3b4c53f":[0,8,353],
+"group__speakerArrangements.html#gaf0c13b30d128debc8f8976927a321f48":[0,8,327],
+"group__speakerArrangements.html#gaf19e8a3b3f0d3a2c0e9587f6cc9b1411":[0,8,168],
+"group__speakerArrangements.html#gaf21f025b23bb45133395657787f88a13":[0,8,133],
+"group__speakerArrangements.html#gaf3da1b6a98e9f9d01e8141f205f35764":[0,8,321],
+"group__speakerArrangements.html#gaf509dd6c5d2edb6286c52038f69b8c7e":[0,8,384],
+"group__speakerArrangements.html#gaf5367c0d3c1ca0a638ecb2dc5198d5a1":[0,8,273],
+"group__speakerArrangements.html#gaf586d67f2382fd76829515ec1a845f0d":[0,8,3],
+"group__speakerArrangements.html#gaf60226cc4b55554791dedf5ac9c6b46c":[0,8,99],
+"group__speakerArrangements.html#gaf610b7be568618c5d5c3aa20d4cf2ecb":[0,8,268],
+"group__speakerArrangements.html#gaf6a1083557b66bb33ab237b2894aa0fa":[0,8,53],
+"group__speakerArrangements.html#gaf7c32506aada727a39b6f30173a5a572":[0,8,176],
+"group__speakerArrangements.html#gaf80df1bbb9f317dd4c11ac891a2f8f40":[0,8,289],
+"group__speakerArrangements.html#gaf949196ba6ad50b12f2522524ae2079a":[0,8,239],
+"group__speakerArrangements.html#gaf9740e0213852cf05d6352dc4132b0df":[0,8,65],
+"group__speakerArrangements.html#gaf980dfe2b66f77f49e5cc064e29baf90":[0,8,202],
+"group__speakerArrangements.html#gafae2531e75a317dd357fa09074fab4f6":[0,8,111],
+"group__speakerArrangements.html#gafbb743a8f1f0002bae234e2d5910ee8a":[0,8,312],
+"group__speakerArrangements.html#gafc605342356ba44807fd1fa424a2bfe5":[0,8,69],
+"group__speakerArrangements.html#gafca48c099db5b486edc4a79616b3f024":[0,8,128],
+"group__speakerArrangements.html#gafd02153e1c7df908d78dba3344573ecb":[0,8,54],
+"group__speakerArrangements.html#gafd2c7f480119d8c17a533fb8d5948fd8":[0,8,155],
+"group__speakerArrangements.html#gafe30ad0333248d38dfd6a162879a97a6":[0,8,323],
+"group__stateType.html":[0,4],
+"group__stateType.html#ga4f34c8d0372a9d06a2713fd488ece66e":[0,4,1],
+"group__stateType.html#ga89eaf816243da36726dfe2656c266a4c":[0,4,0],
+"group__vst3typedef.html":[0,1],
+"group__vst3typedef.html#ga0dc035dac7916366d61df365731f7b63":[0,1,11],
+"group__vst3typedef.html#ga11249ca544d179e7fa61b2200a092407":[0,1,24],
+"group__vst3typedef.html#ga11508dccaa352a24d0ae6585a93f4641":[0,1,15],
+"group__vst3typedef.html#ga1dac5893f4a5c27f986d4e51741b544c":[0,1,16],
+"group__vst3typedef.html#ga1f6dd3f1f6742382e7301c1db5587a4e":[0,1,3],
+"group__vst3typedef.html#ga207b8fd37ea1de019fdb784e4cedacc3":[0,1,5],
+"group__vst3typedef.html#ga353ad4086d31e4b7c57c9124965379a6":[0,1,22],
+"group__vst3typedef.html#ga479361a38cb42c6a07bc6845a5801e55":[0,1,13],
+"group__vst3typedef.html#ga4b750afeaca8056101ac7952543dfd47":[0,1,8],
+"group__vst3typedef.html#ga54884a26d0b6dfa18eb919ea004775ac":[0,1,25],
+"group__vst3typedef.html#ga5b13d028fba1eee386ec9ac208c6238d":[0,1,21],
+"group__vst3typedef.html#ga5b13d028fba1eee386ec9ac208c6238d":[0,1,0],
+"group__vst3typedef.html#ga5f0d28213b308d786ef7a1541d88368f":[0,1,10],
+"group__vst3typedef.html#ga6569c340fc68115670ee0161dd73b3ed":[0,1,14],
+"group__vst3typedef.html#ga7a9fc6561fe897989fa3cea09ebb3250":[0,1,26],
+"group__vst3typedef.html#ga8887669e1feb9270b120bcd725d0d4c1":[0,1,23],
+"group__vst3typedef.html#ga8cd3dd5ea75e76ace81fd1a696544378":[0,1,6],
+"group__vst3typedef.html#ga98965411c9e542b7c2a99a46c8c1dfa2":[0,1,2],
+"group__vst3typedef.html#ga9cc7040d53a88b14ecab90ffb052276d":[0,1,7],
 "group__vst3typedef.html#ga9e134142463a8ca477018e7f2c3220f5":[0,1,4],
 "group__vst3typedef.html#gaa6029db01759d30cfcb3504b84d5d04f":[0,1,12],
 "group__vst3typedef.html#gaa67d0906fec66282a0c9488cb52162f6":[0,1,18],
@@ -38,44 +97,45 @@ var NAVTREEINDEX4 =
 "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31a3b1caa5d658939c027cbb7759358a88a":[3,0,4,9,1],
 "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31af21cd390d9ad5f7929f3f0a3ab972e13":[3,0,4,9,0],
 "ivstaudioprocessor_8h.html#ae55c95a44e931e1cd78998c94bc65ee1":[3,0,4,6],
-"ivstaudioprocessor_8h.html#ga0017ff4ab459880956723e09c847188a":[3,0,4,10],
+"ivstaudioprocessor_8h.html#ga0017ff4ab459880956723e09c847188a":[3,0,4,11],
+"ivstaudioprocessor_8h.html#ga0091b72150adc715454c410d230127e9":[3,0,4,29],
 "ivstaudioprocessor_8h.html#ga01b7fd148c1e5aefa3ea548be3257e50":[3,0,4,25],
-"ivstaudioprocessor_8h.html#ga0280f4b9390e12bf4b4846515572694a":[3,0,4,18],
+"ivstaudioprocessor_8h.html#ga0280f4b9390e12bf4b4846515572694a":[3,0,4,19],
 "ivstaudioprocessor_8h.html#ga0759e804603c37125d02cbc3b091f03b":[3,0,4,23],
-"ivstaudioprocessor_8h.html#ga0ab3065d837d3ed2cb309b61e43e7590":[3,0,4,37],
-"ivstaudioprocessor_8h.html#ga1cbb72f7fd4c011b07e0a249228e54ac":[3,0,4,47],
-"ivstaudioprocessor_8h.html#ga2aea8d0a0d5d5e40680ce5260f52dafd":[3,0,4,22],
-"ivstaudioprocessor_8h.html#ga2dd44f3dc1709680a63b597bac817796":[3,0,4,31],
-"ivstaudioprocessor_8h.html#ga377e6c632bbed63329ad118e1d1f6780":[3,0,4,11],
+"ivstaudioprocessor_8h.html#ga0ab3065d837d3ed2cb309b61e43e7590":[3,0,4,44],
+"ivstaudioprocessor_8h.html#ga1cbb72f7fd4c011b07e0a249228e54ac":[3,0,4,48],
+"ivstaudioprocessor_8h.html#ga2aea8d0a0d5d5e40680ce5260f52dafd":[3,0,4,21],
+"ivstaudioprocessor_8h.html#ga2dd44f3dc1709680a63b597bac817796":[3,0,4,32],
+"ivstaudioprocessor_8h.html#ga377e6c632bbed63329ad118e1d1f6780":[3,0,4,12],
 "ivstaudioprocessor_8h.html#ga4dd95a64193b078cc91d160ae39a95ed":[3,0,4,24],
-"ivstaudioprocessor_8h.html#ga5c37de66c8a6ede53f92d9ea117bbd50":[3,0,4,38],
-"ivstaudioprocessor_8h.html#ga658d80d06b44b28d34628e66c2f1e4e3":[3,0,4,27],
-"ivstaudioprocessor_8h.html#ga6a5beaeb94b8e0a215026ac95f44a6ab":[3,0,4,36],
-"ivstaudioprocessor_8h.html#ga6e00e778267b163458d145a6b6ac37b1":[3,0,4,21],
-"ivstaudioprocessor_8h.html#ga74b483d71fbc43888e605cfdf8b69bd3":[3,0,4,46],
-"ivstaudioprocessor_8h.html#ga793ad8a6c605423f8ca78e6bfacd8e22":[3,0,4,30],
-"ivstaudioprocessor_8h.html#ga81395ffc74210c6b129ac5c1ad0f0450":[3,0,4,16],
-"ivstaudioprocessor_8h.html#ga9584914ab8362461d1bb4bac52ab9fd9":[3,0,4,13],
-"ivstaudioprocessor_8h.html#ga96b0fa2b93633f94d256d0926a23216f":[3,0,4,42],
-"ivstaudioprocessor_8h.html#ga9dbf945372efb065d5f47af0aed0c498":[3,0,4,14],
-"ivstaudioprocessor_8h.html#gaa5ff5ac3ea4de85f61375ed04b2ab88a":[3,0,4,41],
-"ivstaudioprocessor_8h.html#gaadec73a763ae5856f94a1d0ad1335d58":[3,0,4,34],
+"ivstaudioprocessor_8h.html#ga5c37de66c8a6ede53f92d9ea117bbd50":[3,0,4,42],
+"ivstaudioprocessor_8h.html#ga658d80d06b44b28d34628e66c2f1e4e3":[3,0,4,28],
+"ivstaudioprocessor_8h.html#ga6a5beaeb94b8e0a215026ac95f44a6ab":[3,0,4,43],
+"ivstaudioprocessor_8h.html#ga6e00e778267b163458d145a6b6ac37b1":[3,0,4,20],
+"ivstaudioprocessor_8h.html#ga74b483d71fbc43888e605cfdf8b69bd3":[3,0,4,47],
+"ivstaudioprocessor_8h.html#ga793ad8a6c605423f8ca78e6bfacd8e22":[3,0,4,31],
+"ivstaudioprocessor_8h.html#ga81395ffc74210c6b129ac5c1ad0f0450":[3,0,4,10],
+"ivstaudioprocessor_8h.html#ga9584914ab8362461d1bb4bac52ab9fd9":[3,0,4,14],
+"ivstaudioprocessor_8h.html#ga96b0fa2b93633f94d256d0926a23216f":[3,0,4,45],
+"ivstaudioprocessor_8h.html#ga9dbf945372efb065d5f47af0aed0c498":[3,0,4,15],
+"ivstaudioprocessor_8h.html#gaa5ff5ac3ea4de85f61375ed04b2ab88a":[3,0,4,39],
+"ivstaudioprocessor_8h.html#gaadec73a763ae5856f94a1d0ad1335d58":[3,0,4,35],
 "ivstaudioprocessor_8h.html#gab1fff222e0c2b65ce6574afa48e3b838":[3,0,4,40],
-"ivstaudioprocessor_8h.html#gab2264c85ad07f983f365ca1c53489fe3":[3,0,4,28],
-"ivstaudioprocessor_8h.html#gab77fa9595f5503b0d5a49407e1a918c7":[3,0,4,19],
-"ivstaudioprocessor_8h.html#gabd5da3c6aa4168e82cf36eb2c42fac1e":[3,0,4,45],
-"ivstaudioprocessor_8h.html#gac380562898ec7144f4e0ee3b4baa6aa3":[3,0,4,29],
-"ivstaudioprocessor_8h.html#gac5a7bb9551dc86a93bc764efef832164":[3,0,4,39],
-"ivstaudioprocessor_8h.html#gad632f4944a960678d6ff9b3886c878db":[3,0,4,17],
-"ivstaudioprocessor_8h.html#gad8da16bef223355cc58d3b469f876b33":[3,0,4,12],
-"ivstaudioprocessor_8h.html#gadceab87ecf367542d41be60acbdf1f6a":[3,0,4,32],
-"ivstaudioprocessor_8h.html#gadf71323f9881f84038a18a55f9c5693b":[3,0,4,33],
-"ivstaudioprocessor_8h.html#gae0aa5ea7deb453d05ae4a38612d30868":[3,0,4,44],
-"ivstaudioprocessor_8h.html#gaf0d4b7073ef26a60cedee77e04e9f94f":[3,0,4,43],
-"ivstaudioprocessor_8h.html#gaf145d8e7f4ba5cf0b6f8d1373647451f":[3,0,4,15],
-"ivstaudioprocessor_8h.html#gaf9b7f8cfe416744097bfcddfdcced2e6":[3,0,4,26],
-"ivstaudioprocessor_8h.html#gafe3ff646d102a4209512d6cda3b62ac4":[3,0,4,20],
-"ivstaudioprocessor_8h.html#gaffed7482d7d1551379ad26515f4816ef":[3,0,4,35],
+"ivstaudioprocessor_8h.html#gab2264c85ad07f983f365ca1c53489fe3":[3,0,4,22],
+"ivstaudioprocessor_8h.html#gab77fa9595f5503b0d5a49407e1a918c7":[3,0,4,26],
+"ivstaudioprocessor_8h.html#gabd5da3c6aa4168e82cf36eb2c42fac1e":[3,0,4,46],
+"ivstaudioprocessor_8h.html#gac380562898ec7144f4e0ee3b4baa6aa3":[3,0,4,30],
+"ivstaudioprocessor_8h.html#gac5a7bb9551dc86a93bc764efef832164":[3,0,4,41],
+"ivstaudioprocessor_8h.html#gad632f4944a960678d6ff9b3886c878db":[3,0,4,18],
+"ivstaudioprocessor_8h.html#gad8da16bef223355cc58d3b469f876b33":[3,0,4,13],
+"ivstaudioprocessor_8h.html#gadceab87ecf367542d41be60acbdf1f6a":[3,0,4,33],
+"ivstaudioprocessor_8h.html#gadf71323f9881f84038a18a55f9c5693b":[3,0,4,34],
+"ivstaudioprocessor_8h.html#gae0aa5ea7deb453d05ae4a38612d30868":[3,0,4,37],
+"ivstaudioprocessor_8h.html#gaf0d4b7073ef26a60cedee77e04e9f94f":[3,0,4,38],
+"ivstaudioprocessor_8h.html#gaf145d8e7f4ba5cf0b6f8d1373647451f":[3,0,4,16],
+"ivstaudioprocessor_8h.html#gaf9b7f8cfe416744097bfcddfdcced2e6":[3,0,4,27],
+"ivstaudioprocessor_8h.html#gafe3ff646d102a4209512d6cda3b62ac4":[3,0,4,17],
+"ivstaudioprocessor_8h.html#gaffed7482d7d1551379ad26515f4816ef":[3,0,4,36],
 "ivstautomationstate_8h.html":[3,0,5],
 "ivstchannelcontextinfo_8h.html":[3,0,6],
 "ivstchannelcontextinfo_8h.html#a0631a9689c90dab1e9267681bc3d351a":[3,0,6,6],
@@ -189,65 +249,5 @@ var NAVTREEINDEX4 =
 "ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6a9d0c8ad268af6aab096688928d2bf649":[3,0,14,0,3],
 "ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6a9d27c8af6ca2742411edac39853d4063":[3,0,14,0,57],
 "ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6a9db5606058725c95d7196bba2d0177cf":[3,0,14,0,7],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aa1f3100a751b3bd3c521414eb4de9c09":[3,0,14,0,42],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aa2e16c34abda2b690c0ce04f71fba7ed":[3,0,14,0,52],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aa56335dc1a7f013a779d79a2b0766260":[3,0,14,0,38],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aa6ecf7983324f4f64f82e49847306573":[3,0,14,0,55],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aa88e418292a29bb46e148ab9dc999d4b":[3,0,14,0,34],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ab1839eb3b7fd6e17a404d5c549647fcb":[3,0,14,0,48],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ab1c1e0685fcc46278fafff8036837bba":[3,0,14,0,32],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ab9b1ff6e499682378110ba27ecdc0ef7":[3,0,14,0,1],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ab9ded45859a4edeefb3f2c01c9bac04e":[3,0,14,0,9],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aca03cffe46b62bd2c4aab05493e73bb7":[3,0,14,0,56],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6acf538d0974d6427c61c3413b70bca9ba":[3,0,14,0,11],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ad27b2651ac1b6c1bedd2932fd7ceea1e":[3,0,14,0,53],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ad98437cf5dc4611e63d7541e8de2767d":[3,0,14,0,54],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ada4d74f05c77dc221713a293440695d2":[3,0,14,0,49],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ae2b54af4acafdabff72856fa0a2c21ec":[3,0,14,0,13],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6ae5def59ca1557626e92f98eba6bf677f":[3,0,14,0,26],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aede48ecdceaf4750c38194df4e3650d9":[3,0,14,0,37],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6af6ba8b5a08c0e4e7c4d8f6603df78bd5":[3,0,14,0,60],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6af6d59e256dc288cf9012d8e14af1dd72":[3,0,14,0,50],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6af71bc8cfbfd46ba99c8dd6c9b3c098b8":[3,0,14,0,46],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6af7ef2c4385b727d4c937dab21e85f2ee":[3,0,14,0,30],
-"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6afa5ea23fcf3bf9743c9c6565db31a9d9":[3,0,14,0,19],
-"ivstmidilearn_8h.html":[3,0,15],
-"ivstnoteexpression_8h.html":[3,0,16],
-"ivstnoteexpression_8h.html#a62cc12c76af32650e16a6920962ddbf1":[3,0,16,9],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310":[3,0,16,10],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a18860e42c73ce4d8d66d49d6a662ab56":[3,0,16,10,0],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a1c30475ef992f89f37c2fe0aafcc6283":[3,0,16,10,8],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a2c5cacda2fb1b13fb3bce937819bf1f9":[3,0,16,10,9],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a3eb020a0ad7005b2be7b70e373cc4431":[3,0,16,10,5],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a4ebd202862aff5265a6c1bcd901bd5b8":[3,0,16,10,7],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a5e7ae2b2c476af4e9cdfd62902d68880":[3,0,16,10,4],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a7148e2b1e53d751df8801134fa2059f8":[3,0,16,10,1],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a77f4a0bbec04c57e50441d58dddc753e":[3,0,16,10,6],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310a9fadf3f8d95dee835c8a0dcc9605b5af":[3,0,16,10,3],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310ac196000d5497502327e2b4f69e5037be":[3,0,16,10,2],
-"ivstnoteexpression_8h.html#a7d66c573aff27d890ec154f45b61f310ae9353615a5098aba2a5dc927d5497132":[3,0,16,10,10],
-"ivstnoteexpression_8h.html#a94ba59b05ac09e4f021b5cd0955852c9":[3,0,16,11],
-"ivstnoteexpression_8h.html#a94ba59b05ac09e4f021b5cd0955852c9a0e2daa9cc892408b666cfdda855652c0":[3,0,16,11,2],
-"ivstnoteexpression_8h.html#a94ba59b05ac09e4f021b5cd0955852c9a19aaecc29b830ac94b9804b3f6b1aebb":[3,0,16,11,0],
-"ivstnoteexpression_8h.html#a94ba59b05ac09e4f021b5cd0955852c9a585a87fa2b02e4aaf5e3280df2bb41c1":[3,0,16,11,1],
-"ivstnoteexpression_8h.html#a94ba59b05ac09e4f021b5cd0955852c9abf9a3d392f6bd3ad7f0db013fd5dbc18":[3,0,16,11,3],
-"ivstnoteexpression_8h.html#ga1f6dd3f1f6742382e7301c1db5587a4e":[3,0,16,7],
-"ivstnoteexpression_8h.html#ga9e134142463a8ca477018e7f2c3220f5":[3,0,16,8],
-"ivstparameterchanges_8h.html":[3,0,17],
-"ivstparameterfunctionname_8h.html":[3,0,18],
-"ivstparameterfunctionname_8h.html#a0bd06431d3d5836bce03edd612419757":[3,0,18,2],
-"ivstparameterfunctionname_8h.html#a108cdff90ad44efad08520aa4af2a891":[3,0,18,6],
-"ivstparameterfunctionname_8h.html#a37ae311e898bd4a7706dfbe8cbde54ac":[3,0,18,3],
-"ivstparameterfunctionname_8h.html#a63823edb3c1ddcdd21173e9dc35c172c":[3,0,18,4],
-"ivstparameterfunctionname_8h.html#a7e3eaee867bebf92ee98e6e19de3d7df":[3,0,18,7],
-"ivstparameterfunctionname_8h.html#a850c37b07b8d83b79d308a151668cb59":[3,0,18,10],
-"ivstparameterfunctionname_8h.html#a95060bef8cd2b144050c98326dccf13d":[3,0,18,1],
-"ivstparameterfunctionname_8h.html#ab4ab5d97708547af9600017e134a225f":[3,0,18,9],
-"ivstparameterfunctionname_8h.html#ad875faf2282aeb70781130ed7e8de2b9":[3,0,18,8],
-"ivstparameterfunctionname_8h.html#af4be690372df7b16a930d2207e408402":[3,0,18,5],
-"ivstphysicalui_8h.html":[3,0,19],
-"ivstphysicalui_8h.html#a625d3c836663769a5ea9df6a8481feca":[3,0,19,4],
-"ivstphysicalui_8h.html#a625d3c836663769a5ea9df6a8481fecaa5515be4e86335bb5c9980377784d3cfd":[3,0,19,4,3],
-"ivstphysicalui_8h.html#a625d3c836663769a5ea9df6a8481fecaa8b27cb6543ac07a669439676746fb05f":[3,0,19,4,1],
-"ivstphysicalui_8h.html#a625d3c836663769a5ea9df6a8481fecaa973abf8a1ca38781df5550b5db3ed345":[3,0,19,4,0]
+"ivstmidicontrollers_8h.html#a70ee68a13248febed5047cfa0fddf4e6aa1f3100a751b3bd3c521414eb4de9c09":[3,0,14,0,42]
 };
