@@ -1,5 +1,65 @@
 var NAVTREEINDEX6 =
 {
+"structSteinberg_1_1Vst_1_1BusInfo.html#a764af5c5b921de1cab2eca6565ea5d1e":[0,2,0,0],
+"structSteinberg_1_1Vst_1_1BusInfo.html#a764af5c5b921de1cab2eca6565ea5d1eace2379dbcd61f72660abb9243cb55bc6":[0,2,0,0,0],
+"structSteinberg_1_1Vst_1_1BusInfo.html#a764af5c5b921de1cab2eca6565ea5d1ead4866d347690f538cd3dd9ba04af86d6":[0,2,0,0,1],
+"structSteinberg_1_1Vst_1_1BusInfo.html#a795177c339bd0b25de0ea4189aa6c893":[0,2,0,5],
+"structSteinberg_1_1Vst_1_1BusInfo.html#a81a27ce50e78368b0d0de1e8767fd32d":[0,2,0,6],
+"structSteinberg_1_1Vst_1_1BusInfo.html#ab22e24964d55652336d526a41e5a2309":[0,2,0,3],
+"structSteinberg_1_1Vst_1_1BusInfo.html#abb6aef5950e795ec6507d07a5c8bd4fe":[0,2,0,2],
+"structSteinberg_1_1Vst_1_1BusInfo.html#ac12e8d0c4308238a04fefe98e39b1514":[0,2,0,1],
+"structSteinberg_1_1Vst_1_1Chord.html":[2,0,0,1,76],
+"structSteinberg_1_1Vst_1_1Chord.html#a15c053e1a487c607ed4f57d29a07e117":[2,0,0,1,76,0],
+"structSteinberg_1_1Vst_1_1Chord.html#a15c053e1a487c607ed4f57d29a07e117a4604f8115055d6e83aa00610b65a290c":[2,0,0,1,76,0,1],
+"structSteinberg_1_1Vst_1_1Chord.html#a15c053e1a487c607ed4f57d29a07e117a7eebe88f8cafca853fd115af0e1939ab":[2,0,0,1,76,0,0],
+"structSteinberg_1_1Vst_1_1Chord.html#a4aaf84930c8913e7e3712874f2a5e04a":[2,0,0,1,76,1],
+"structSteinberg_1_1Vst_1_1Chord.html#a618acffbc29c4bc4ba7ffd114686c235":[2,0,0,1,76,2],
+"structSteinberg_1_1Vst_1_1Chord.html#aeaf52509d7189fb85cfab0c24549bfce":[2,0,0,1,76,3],
+"structSteinberg_1_1Vst_1_1ChordEvent.html":[2,0,0,1,44],
+"structSteinberg_1_1Vst_1_1ChordEvent.html#a109c9addbf0865629fcb10fede22de26":[2,0,0,1,44,0],
+"structSteinberg_1_1Vst_1_1ChordEvent.html#a4f5c7e14d27cd2000f90c5fca2adb9a7":[2,0,0,1,44,1],
+"structSteinberg_1_1Vst_1_1ChordEvent.html#a4f6335dfe1239867b906eb8a304b5984":[2,0,0,1,44,3],
+"structSteinberg_1_1Vst_1_1ChordEvent.html#a831873f40a39122089d004e06f800d17":[2,0,0,1,44,2],
+"structSteinberg_1_1Vst_1_1ChordEvent.html#aa87f60a3f4718be230eba436bdd0d610":[2,0,0,1,44,4],
+"structSteinberg_1_1Vst_1_1DataEvent.html":[2,0,0,1,42],
+"structSteinberg_1_1Vst_1_1DataEvent.html#a0d40f1591c12f359c3fa3f982f9a221d":[2,0,0,1,42,1],
+"structSteinberg_1_1Vst_1_1DataEvent.html#ab0e4bfcd0606119dacd07fd9388de747":[2,0,0,1,42,3],
+"structSteinberg_1_1Vst_1_1DataEvent.html#af356674bbaaf9bb782af79059eef1346":[2,0,0,1,42,2],
+"structSteinberg_1_1Vst_1_1DataEvent.html#afb6eb4f28419b652027fad41104a6d22":[2,0,0,1,42,0],
+"structSteinberg_1_1Vst_1_1DataEvent.html#afb6eb4f28419b652027fad41104a6d22ab06d86440be6a85eccce4df100ce8e79":[2,0,0,1,42,0,0],
+"structSteinberg_1_1Vst_1_1Event.html":[2,0,0,1,47],
+"structSteinberg_1_1Vst_1_1Event.html#a0f35f105b944d86baed64153c9544b38":[2,0,0,1,47,11],
+"structSteinberg_1_1Vst_1_1Event.html#a21c98848a005b27ed5ed3951555d94a5":[2,0,0,1,47,8],
+"structSteinberg_1_1Vst_1_1Event.html#a3f45fbed968cf574aa1f9b859f0a0972":[2,0,0,1,47,15],
+"structSteinberg_1_1Vst_1_1Event.html#a4f0bc42a72c611ac6c177661d617b6dc":[2,0,0,1,47,9],
+"structSteinberg_1_1Vst_1_1Event.html#a5da7304404b66954c04f2c61242b4336":[2,0,0,1,47,4],
+"structSteinberg_1_1Vst_1_1Event.html#a7bd5bf2b37708149b2c318f8fd669d50":[2,0,0,1,47,12],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8":[2,0,0,1,47,1],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a18b62187f591a8e615ef6c934461db2d":[2,0,0,1,47,1,4],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a1cabbcf11ce8779b94e6cfa480d87b09":[2,0,0,1,47,1,1],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a1fcf9cd0ded093f84e9b0a8177679ad4":[2,0,0,1,47,1,7],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a494e407c199f55129c93f53bd5cada93":[2,0,0,1,47,1,5],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a4e0a8c28a95df34b9c12c0f226e6923d":[2,0,0,1,47,1,6],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a5800a14018dee96cd41f5f10691b8b85":[2,0,0,1,47,1,3],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a62a25bd1cd5f061e9897cc7315f6763a":[2,0,0,1,47,1,2],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a6969fd08df9f0611a6566e93c0c31e42":[2,0,0,1,47,1,0],
+"structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a85daeaf98e74f3c670b9939c78794b95":[2,0,0,1,47,1,8],
+"structSteinberg_1_1Vst_1_1Event.html#a990c632f42079b7d085d2b3747e2e919":[2,0,0,1,47,13],
+"structSteinberg_1_1Vst_1_1Event.html#a9b2081be7783cb98c534aa1ff955ac5c":[2,0,0,1,47,3],
+"structSteinberg_1_1Vst_1_1Event.html#aa5ba30ca69cff19d9c45599238388230":[2,0,0,1,47,14],
+"structSteinberg_1_1Vst_1_1Event.html#aa7ce3c35c89b80c286a732eb1794307c":[2,0,0,1,47,7],
+"structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5":[2,0,0,1,47,0],
+"structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5a62708aba77581182dffd7458cf6b621e":[2,0,0,1,47,0,1],
+"structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5a8b9e49c3d94641913c8098c23c25b125":[2,0,0,1,47,0,0],
+"structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5aa0fac77d8173c8ca51fb73ae6177181b":[2,0,0,1,47,0,2],
+"structSteinberg_1_1Vst_1_1Event.html#acc27ddf2b1e504795c7724921eb57286":[2,0,0,1,47,10],
+"structSteinberg_1_1Vst_1_1Event.html#acd2bbbb2eae99e9e00ac1517dbf7958d":[2,0,0,1,47,2],
+"structSteinberg_1_1Vst_1_1Event.html#ae15f0808741c35cb9a8d231105d8beea":[2,0,0,1,47,5],
+"structSteinberg_1_1Vst_1_1Event.html#af9b2e23a8f32ca09cfeb7d828436fb01":[2,0,0,1,47,6],
+"structSteinberg_1_1Vst_1_1FrameRate.html":[2,0,0,1,75],
+"structSteinberg_1_1Vst_1_1FrameRate.html#a0e1b90fc53cc88f751388bc4466a4665":[2,0,0,1,75,0],
+"structSteinberg_1_1Vst_1_1FrameRate.html#a0e1b90fc53cc88f751388bc4466a4665a859f363f2bc4f6bb60331d4106870722":[2,0,0,1,75,0,1],
+"structSteinberg_1_1Vst_1_1FrameRate.html#a0e1b90fc53cc88f751388bc4466a4665aa2055ed514ccc81c537ca60ddbdaa226":[2,0,0,1,75,0,0],
 "structSteinberg_1_1Vst_1_1FrameRate.html#a81a27ce50e78368b0d0de1e8767fd32d":[2,0,0,1,75,2],
 "structSteinberg_1_1Vst_1_1FrameRate.html#a9f29f1e74507c8ad3d1be129fc8b7b53":[2,0,0,1,75,1],
 "structSteinberg_1_1Vst_1_1IContextMenuItem.html":[2,0,0,1,29],
@@ -189,65 +249,5 @@ var NAVTREEINDEX6 =
 "vstpresetkeys_8h.html#ga084d4ed63922f00549f31a1114ecd32c":[3,0,27,288],
 "vstpresetkeys_8h.html#ga09ada6780ac854e1a5f5fdeaeed3fb98":[3,0,27,99],
 "vstpresetkeys_8h.html#ga09caf2a39534495b771aa65a0d969ad1":[3,0,27,225],
-"vstpresetkeys_8h.html#ga0ade597c6d17afc9e6cf4a7bdf34de9b":[3,0,27,183],
-"vstpresetkeys_8h.html#ga0bbfdd92cc2b2313b3cf974c5b3f9760":[3,0,27,251],
-"vstpresetkeys_8h.html#ga0bc38b1dfd75d0ae9e6137d43c29068c":[3,0,27,256],
-"vstpresetkeys_8h.html#ga0cc2d58842ce2dcad93a3f83a777a67d":[3,0,27,26],
-"vstpresetkeys_8h.html#ga0d9c9e5d1d7762b13270a0cd388b2d7e":[3,0,27,129],
-"vstpresetkeys_8h.html#ga0e5caac1dbaa9755fdb06e89ed3b3895":[3,0,27,32],
-"vstpresetkeys_8h.html#ga0ee890f05a7479865af9eda6d34bc857":[3,0,27,188],
-"vstpresetkeys_8h.html#ga10904a318940018e74802140f840a4cc":[3,0,27,247],
-"vstpresetkeys_8h.html#ga11ef28f0a9918a82c981b1fb8025bd8b":[3,0,27,33],
-"vstpresetkeys_8h.html#ga12eb4bbef0c030bbca1e861adc773334":[3,0,27,34],
-"vstpresetkeys_8h.html#ga13e10384c541982e7ebea23ae4cc0057":[3,0,27,177],
-"vstpresetkeys_8h.html#ga13f91d403c87da4936308cd2f94b3dce":[3,0,27,13],
-"vstpresetkeys_8h.html#ga13fca99a8c4598a5f66ef87242f70b27":[3,0,27,42],
-"vstpresetkeys_8h.html#ga1578d35d598b30c1a8aca33c94e33213":[3,0,27,162],
-"vstpresetkeys_8h.html#ga166d8e939e25f23c6e1c5125e89d5f13":[3,0,27,4],
-"vstpresetkeys_8h.html#ga17f0e511cbcdedf14156ba499a54d615":[3,0,27,226],
-"vstpresetkeys_8h.html#ga18049d58eeecea7c6fed4f727442430d":[3,0,27,238],
-"vstpresetkeys_8h.html#ga1835577b20a8f992869f11555b9c6c43":[3,0,27,19],
-"vstpresetkeys_8h.html#ga18f27017b00ca4612f133f4e09d913e3":[3,0,27,241],
-"vstpresetkeys_8h.html#ga196114f5b784b26e46ca975e194a12cc":[3,0,27,274],
-"vstpresetkeys_8h.html#ga19fc8fcee1d6326b028fdeace97da264":[3,0,27,282],
-"vstpresetkeys_8h.html#ga1a1b8c73dee78995dfc73a9cbe1855fa":[3,0,27,152],
-"vstpresetkeys_8h.html#ga1a4ba62937d8347b92bd6a7fe2f0f203":[3,0,27,21],
-"vstpresetkeys_8h.html#ga1abdca80184a162d425c61f053530dea":[3,0,27,138],
-"vstpresetkeys_8h.html#ga1af05a3bfb82be1b619388c384a6bf2d":[3,0,27,80],
-"vstpresetkeys_8h.html#ga1b380d79f09e7bd56403f79f09514db9":[3,0,27,280],
-"vstpresetkeys_8h.html#ga1b594039765ec814407ab25b574177e3":[3,0,27,119],
-"vstpresetkeys_8h.html#ga1b66689bf69717c4af8ad85835737acf":[3,0,27,205],
-"vstpresetkeys_8h.html#ga1baec415d4b38bfc63bfe37d4d8f998e":[3,0,27,98],
-"vstpresetkeys_8h.html#ga1d83ca1c98b52785de6b205cf10ba2cc":[3,0,27,276],
-"vstpresetkeys_8h.html#ga1e43c81772b3227d2239c4c869194733":[3,0,27,207],
-"vstpresetkeys_8h.html#ga1e4a49eeaaedbf8487070bf20a06b119":[3,0,27,24],
-"vstpresetkeys_8h.html#ga1f2c119eb1f5ed7687375950e64a099a":[3,0,27,23],
-"vstpresetkeys_8h.html#ga20c97efa4d9bc8307bbd0375035c34ae":[3,0,27,65],
-"vstpresetkeys_8h.html#ga20f011a1e399ecacdb0e6e1cb7196e64":[3,0,27,76],
-"vstpresetkeys_8h.html#ga21365983f34c81eb766d77a9f6c56542":[3,0,27,104],
-"vstpresetkeys_8h.html#ga2283c2c777c7cbb21710e11ef2ceb6af":[3,0,27,126],
-"vstpresetkeys_8h.html#ga2390a2a94e9904517ec9342ab0019fe7":[3,0,27,66],
-"vstpresetkeys_8h.html#ga24192885baa2c896f4ac92a68e176802":[3,0,27,286],
-"vstpresetkeys_8h.html#ga24447081033911845dd5279102bf075b":[3,0,27,224],
-"vstpresetkeys_8h.html#ga265f017e0f464df3d4141dc319eff0c7":[3,0,27,89],
-"vstpresetkeys_8h.html#ga27a783d5bce0708e88414cd4de0ffc3b":[3,0,27,170],
-"vstpresetkeys_8h.html#ga280fd77ca4f703e3509ba81e6a4a7062":[3,0,27,272],
-"vstpresetkeys_8h.html#ga2acd1ccf8c493d7055288674c243e7f0":[3,0,27,164],
-"vstpresetkeys_8h.html#ga2b8b2179cf8d2b74f6c0eb2abb563a80":[3,0,27,130],
-"vstpresetkeys_8h.html#ga2d5f12d8f479275a1ec1047877ad12f6":[3,0,27,109],
-"vstpresetkeys_8h.html#ga2ec0df01bea69ecba86f5d891b1ad648":[3,0,27,74],
-"vstpresetkeys_8h.html#ga3030eff3a0900a8cca1c6266716efe1e":[3,0,27,258],
-"vstpresetkeys_8h.html#ga3089241b92ddf52d670f6339c57ff321":[3,0,27,216],
-"vstpresetkeys_8h.html#ga310f8f745367f1fff3d176974abb507f":[3,0,27,279],
-"vstpresetkeys_8h.html#ga31d1f86b5f8a0281d2a85f7ae6e40d10":[3,0,27,218],
-"vstpresetkeys_8h.html#ga326410320556a12f64c20f88c19373ce":[3,0,27,63],
-"vstpresetkeys_8h.html#ga33320722a4e37a0dbe61f8957a77fcb8":[3,0,27,136],
-"vstpresetkeys_8h.html#ga33a8a991563a9d73923525ddd29e79a0":[3,0,27,231],
-"vstpresetkeys_8h.html#ga33b0df9f2de9caa850ec8f42a690ea1c":[3,0,27,110],
-"vstpresetkeys_8h.html#ga341e53ab2df394405b3785850dad88e9":[3,0,27,84],
-"vstpresetkeys_8h.html#ga351f0ed74b2185f5acc3460021c203a6":[3,0,27,40],
-"vstpresetkeys_8h.html#ga370c692d8ab858d11bff12c0ea4c779c":[3,0,27,206],
-"vstpresetkeys_8h.html#ga37d4c3eca4f4d9c151ffa65609c79439":[3,0,27,79],
-"vstpresetkeys_8h.html#ga37e6e5e54e1d052d21d739a032593282":[3,0,27,287],
-"vstpresetkeys_8h.html#ga3ae32b316261fa76c8d7ca0e9790871f":[3,0,27,229]
+"vstpresetkeys_8h.html#ga0ade597c6d17afc9e6cf4a7bdf34de9b":[3,0,27,183]
 };
