@@ -135,15 +135,17 @@ var NAVTREEINDEX3 =
 "classVST3_1_1Hosting_1_1FactoryInfo.html#ac8ad2adb1f6d6a880cf49fb3a8e0f376":[4,0,1,0,0,6],
 "classVST3_1_1Hosting_1_1FactoryInfo.html#ade5e95be16c18ad29aa128536f6930af":[4,0,1,0,0,2],
 "classVST3_1_1Hosting_1_1Module.html":[4,0,1,0,3],
-"classVST3_1_1Hosting_1_1Module.html#a4d455efceee21e97d8e21ee40e9b4a20":[4,0,1,0,3,11],
+"classVST3_1_1Hosting_1_1Module.html#a4d455efceee21e97d8e21ee40e9b4a20":[4,0,1,0,3,12],
 "classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15":[4,0,1,0,3,1],
-"classVST3_1_1Hosting_1_1Module.html#a7ddbf523610d9a2456ef7b40f1ef488e":[4,0,1,0,3,9],
+"classVST3_1_1Hosting_1_1Module.html#a732849e7293ae526d692dc14ca2faa5e":[4,0,1,0,3,8],
+"classVST3_1_1Hosting_1_1Module.html#a7ddbf523610d9a2456ef7b40f1ef488e":[4,0,1,0,3,10],
 "classVST3_1_1Hosting_1_1Module.html#a9424de46a29175d2e1687b5256496587":[4,0,1,0,3,3],
-"classVST3_1_1Hosting_1_1Module.html#a9b45b3e13bd9167aab02e17e08916231":[4,0,1,0,3,10],
+"classVST3_1_1Hosting_1_1Module.html#a9b45b3e13bd9167aab02e17e08916231":[4,0,1,0,3,11],
 "classVST3_1_1Hosting_1_1Module.html#aaa8f4978d4cd166724c0856b02208dab":[4,0,1,0,3,4],
 "classVST3_1_1Hosting_1_1Module.html#acdb10dcad8762c5983d925df70f95732":[4,0,1,0,3,2],
-"classVST3_1_1Hosting_1_1Module.html#ad210dec17843e489c4c87cb1d401444c":[4,0,1,0,3,8],
+"classVST3_1_1Hosting_1_1Module.html#ad210dec17843e489c4c87cb1d401444c":[4,0,1,0,3,9],
 "classVST3_1_1Hosting_1_1Module.html#adbf9f5b3b8a667bdbbfc3928108b09aa":[4,0,1,0,3,6],
+"classVST3_1_1Hosting_1_1Module.html#ae9087247e1a6e9b3d267c9546b4f8762":[4,0,1,0,3,13],
 "classVST3_1_1Hosting_1_1Module.html#ae97c2724ea480d85272ba2cb5a1da524":[4,0,1,0,3,5],
 "classVST3_1_1Hosting_1_1Module.html#af02425e760491b6944e5a9868e9e770e":[4,0,1,0,3,7],
 "classVST3_1_1Hosting_1_1PluginFactory.html":[4,0,1,0,2],
@@ -216,8 +218,8 @@ var NAVTREEINDEX3 =
 "functions_0x7e.html":[4,3,0,24],
 "functions_enum.html":[4,3,4],
 "functions_eval.html":[4,3,5],
-"functions_func.html":[4,3,1,0],
 "functions_func.html":[4,3,1],
+"functions_func.html":[4,3,1,0],
 "functions_func_0x62.html":[4,3,1,1],
 "functions_func_0x63.html":[4,3,1,2],
 "functions_func_0x64.html":[4,3,1,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX3 =
 "globals_defs.html":[5,1,5],
 "globals_enum.html":[5,1,4],
 "globals_func.html":[5,1,1],
-"globals_type.html":[5,1,3],
-"globals_vars.html":[5,1,2],
-"group__hostingBase.html":[2,2]
+"globals_type.html":[5,1,3]
 };
