@@ -1,5 +1,7 @@
 var NAVTREEINDEX4 =
 {
+"globals_vars.html":[5,1,2],
+"group__hostingBase.html":[2,2],
 "group__sdkBase.html":[2,1],
 "group__vstClasses.html":[2,0],
 "hierarchy.html":[4,2],
@@ -34,11 +36,13 @@ var NAVTREEINDEX4 =
 "module__mac_8mm.html#a4646f121b3a9e74f96ecf21c6e24b4ec":[5,0,38,0],
 "module__mac_8mm.html#a506bad6939b58350ec480b5acbdee6c4":[5,0,38,1],
 "module__win32_8cpp.html":[5,0,39],
-"module__win32_8cpp.html#a41ef2c2b409468fd271243d107c85e12":[5,0,39,5],
-"module__win32_8cpp.html#a56b0f237e07f0782cc40b2e9f12d4a92":[5,0,39,4],
+"module__win32_8cpp.html#a41ef2c2b409468fd271243d107c85e12":[5,0,39,7],
+"module__win32_8cpp.html#a56b0f237e07f0782cc40b2e9f12d4a92":[5,0,39,5],
 "module__win32_8cpp.html#a8412a3c25d49cee5637408e60384ae2c":[5,0,39,0],
 "module__win32_8cpp.html#aab6af62131aad81d17d3b4afd9db334f":[5,0,39,1],
-"module__win32_8cpp.html#ab960ef10cf6ba5f66c273a348d70cef7":[5,0,39,3],
+"module__win32_8cpp.html#ab960ef10cf6ba5f66c273a348d70cef7":[5,0,39,4],
+"module__win32_8cpp.html#aba0050d0d9182386e51d25ec355f4f8d":[5,0,39,3],
+"module__win32_8cpp.html#adc18f3cbe8d2b92a8350abbed9157fab":[5,0,39,6],
 "module__win32_8cpp.html#af1ce76814dd30ab1a712aaee424a9525":[5,0,39,2],
 "modules.html":[2],
 "mpeprocessor_8cpp.html":[5,0,40],
@@ -59,10 +63,10 @@ var NAVTREEINDEX4 =
 "mpeprocessor_8h.html#ab38d25bdae264eebd969558d1a01425b":[5,0,41,7],
 "mpeprocessor_8h.html#ab4311216475ec4d94c471bb87ed1721e":[5,0,41,3],
 "mpeprocessor_8h.html#acc0ccc0e35cb8a064d3b1675fbef9d44":[5,0,41,4],
-"namespaceSteinberg_1_1OneReaderOneWriter.html":[4,0,0,2],
 "namespaceSteinberg_1_1OneReaderOneWriter.html":[3,0,0,2],
-"namespaceSteinberg_1_1Vst_1_1Algo.html":[3,0,0,1,0],
+"namespaceSteinberg_1_1OneReaderOneWriter.html":[4,0,0,2],
 "namespaceSteinberg_1_1Vst_1_1Algo.html":[4,0,0,1,0],
+"namespaceSteinberg_1_1Vst_1_1Algo.html":[3,0,0,1,0],
 "namespaceSteinberg_1_1Vst_1_1Helpers.html":[3,0,0,1,1],
 "namespaceSteinberg_1_1Vst_1_1Helpers.html":[4,0,0,1,1],
 "namespaceSteinberg_1_1Vst_1_1InterAppAudio.html":[4,0,0,1,2],
@@ -71,16 +75,16 @@ var NAVTREEINDEX4 =
 "namespaceSteinberg_1_1Vst_1_1MPE.html":[3,0,0,1,3],
 "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html":[4,0,0,1,4],
 "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html":[3,0,0,1,4],
-"namespaceSteinberg_1_1Vst_1_1Test.html":[4,0,0,1,5],
 "namespaceSteinberg_1_1Vst_1_1Test.html":[3,0,0,1,5],
-"namespaceVST3.html":[3,0,1],
+"namespaceSteinberg_1_1Vst_1_1Test.html":[4,0,0,1,5],
 "namespaceVST3.html":[4,0,1],
-"namespaceVST3_1_1Hosting.html":[3,0,1,0],
+"namespaceVST3.html":[3,0,1],
 "namespaceVST3_1_1Hosting.html":[4,0,1,0],
+"namespaceVST3_1_1Hosting.html":[3,0,1,0],
 "namespaceVST3_1_1IO.html":[3,0,1,2],
 "namespaceVST3_1_1IO.html":[4,0,1,2],
-"namespaceVST3_1_1StringConvert.html":[3,0,1,1],
 "namespaceVST3_1_1StringConvert.html":[4,0,1,1],
+"namespaceVST3_1_1StringConvert.html":[3,0,1,1],
 "namespaceVSTGUI.html":[4,0,2],
 "namespaceVSTGUI.html":[3,0,2],
 "namespacemembers.html":[3,1,0],
@@ -120,6 +124,7 @@ var NAVTREEINDEX4 =
 "stringconvert_8cpp.html#ad0e56044e282dcac7890cbce544aa83f":[5,0,68,4],
 "stringconvert_8h.html":[5,0,69],
 "stringconvert_8h.html#a207e23e9cafce1b77acf9da2f72f2fc9":[5,0,69,7],
+"stringconvert_8h.html#a4057efa382a8c98391f469c2a6f98ac5":[5,0,69,8],
 "stringconvert_8h.html#a516c6fb6f3feea42db8958f97e146129":[5,0,69,2],
 "stringconvert_8h.html#a7b24e433664bafa3dd3f9357ec3f6c4d":[5,0,69,0],
 "stringconvert_8h.html#a931b7bcc1c22509766093e32f28d2e23":[5,0,69,3],
@@ -137,8 +142,8 @@ var NAVTREEINDEX4 =
 "structSteinberg_1_1ObjCInstance.html":[4,0,0,4],
 "structSteinberg_1_1ObjCInstance.html#a40d1c81cfa49dd2dae47e5ee0a678046":[4,0,0,4,2],
 "structSteinberg_1_1ObjCInstance.html#a6ecc79aa4806e0f3bf894b850c626ec8":[4,0,0,4,1],
-"structSteinberg_1_1ObjCInstance.html#abbc08583bad201e05a3391abce644ddc":[4,0,0,4,0],
 "structSteinberg_1_1ObjCInstance.html#ac9a665bd38b225c0e9d00c3198001b46":[4,0,0,4,3],
+"structSteinberg_1_1ObjCInstance.html#af297da87bd0771fcecdc2f796385b5d1":[4,0,0,4,0],
 "structSteinberg_1_1ObjCVariable.html":[4,0,0,3],
 "structSteinberg_1_1ObjCVariable.html#a0f806efa754adc9f722b43aabba42dd4":[4,0,0,3,4],
 "structSteinberg_1_1ObjCVariable.html#a62cd47bc16e8d305970d9e2c5aca9b41":[4,0,0,3,0],
@@ -244,10 +249,5 @@ var NAVTREEINDEX4 =
 "structVST3_1_1Optional.html#a7d06aa7be1fba3def55cb3cd7decec05":[4,0,1,3,10],
 "structVST3_1_1Optional.html#a907da3f5e7b107340832dd56f1b89a49":[4,0,1,3,6],
 "structVST3_1_1Optional.html#aa3d0d858d5f575eea729f08dbf899a0c":[4,0,1,3,8],
-"structVST3_1_1Optional.html#ac8ca315e2d3167179848e63908301447":[4,0,1,3,11],
-"structVST3_1_1Optional.html#ad88a9874027d44e9ec4007ef3ba55b25":[4,0,1,3,9],
-"structVST3_1_1Optional.html#af6328c0ea9be2732e7640165c9dcbd82":[4,0,1,3,2],
-"structVST3_1_1UID.html":[4,0,1,4],
-"structVST3_1_1UID.html#a01a8fca87886bc6721818c064169732a":[4,0,1,4,2],
-"structVST3_1_1UID.html#a20b2abb54d43add1d16c4c4660c43922":[4,0,1,4,8]
+"structVST3_1_1Optional.html#ac8ca315e2d3167179848e63908301447":[4,0,1,3,11]
 };
